/* Branch.c generated by valac 0.36.6, the Vala compiler
 * generated from Branch.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */

#include <glib.h>
#include <glib-object.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <gdk/gdk.h>
#include <glib/gi18n-lib.h>
#include <gio/gio.h>


#define SIDEBAR_TYPE_BRANCH (sidebar_branch_get_type ())
#define SIDEBAR_BRANCH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_BRANCH, SidebarBranch))
#define SIDEBAR_BRANCH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SIDEBAR_TYPE_BRANCH, SidebarBranchClass))
#define SIDEBAR_IS_BRANCH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_BRANCH))
#define SIDEBAR_IS_BRANCH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SIDEBAR_TYPE_BRANCH))
#define SIDEBAR_BRANCH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SIDEBAR_TYPE_BRANCH, SidebarBranchClass))

typedef struct _SidebarBranch SidebarBranch;
typedef struct _SidebarBranchClass SidebarBranchClass;
typedef struct _SidebarBranchPrivate SidebarBranchPrivate;

#define TAGS_TYPE_BRANCH (tags_branch_get_type ())
#define TAGS_BRANCH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TAGS_TYPE_BRANCH, TagsBranch))
#define TAGS_BRANCH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TAGS_TYPE_BRANCH, TagsBranchClass))
#define TAGS_IS_BRANCH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TAGS_TYPE_BRANCH))
#define TAGS_IS_BRANCH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TAGS_TYPE_BRANCH))
#define TAGS_BRANCH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TAGS_TYPE_BRANCH, TagsBranchClass))

typedef struct _TagsBranch TagsBranch;
typedef struct _TagsBranchClass TagsBranchClass;
typedef struct _TagsBranchPrivate TagsBranchPrivate;

#define TYPE_DATA_OBJECT (data_object_get_type ())
#define DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_OBJECT, DataObject))
#define DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_OBJECT, DataObjectClass))
#define IS_DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_OBJECT))
#define IS_DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_OBJECT))
#define DATA_OBJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_OBJECT, DataObjectClass))

typedef struct _DataObject DataObject;
typedef struct _DataObjectClass DataObjectClass;

#define TYPE_DATA_SOURCE (data_source_get_type ())
#define DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_SOURCE, DataSource))
#define DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_SOURCE, DataSourceClass))
#define IS_DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_SOURCE))
#define IS_DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_SOURCE))
#define DATA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_SOURCE, DataSourceClass))

typedef struct _DataSource DataSource;
typedef struct _DataSourceClass DataSourceClass;

#define TYPE_TAG (tag_get_type ())
#define TAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TAG, Tag))
#define TAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TAG, TagClass))
#define IS_TAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TAG))
#define IS_TAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TAG))
#define TAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TAG, TagClass))

typedef struct _Tag Tag;
typedef struct _TagClass TagClass;

#define SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY (sidebar_simple_page_entry_get_type ())
#define SIDEBAR_SIMPLE_PAGE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY, SidebarSimplePageEntry))
#define SIDEBAR_SIMPLE_PAGE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY, SidebarSimplePageEntryClass))
#define SIDEBAR_IS_SIMPLE_PAGE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY))
#define SIDEBAR_IS_SIMPLE_PAGE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY))
#define SIDEBAR_SIMPLE_PAGE_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY, SidebarSimplePageEntryClass))

typedef struct _SidebarSimplePageEntry SidebarSimplePageEntry;
typedef struct _SidebarSimplePageEntryClass SidebarSimplePageEntryClass;

#define TAGS_TYPE_SIDEBAR_ENTRY (tags_sidebar_entry_get_type ())
#define TAGS_SIDEBAR_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TAGS_TYPE_SIDEBAR_ENTRY, TagsSidebarEntry))
#define TAGS_SIDEBAR_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TAGS_TYPE_SIDEBAR_ENTRY, TagsSidebarEntryClass))
#define TAGS_IS_SIDEBAR_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TAGS_TYPE_SIDEBAR_ENTRY))
#define TAGS_IS_SIDEBAR_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TAGS_TYPE_SIDEBAR_ENTRY))
#define TAGS_SIDEBAR_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TAGS_TYPE_SIDEBAR_ENTRY, TagsSidebarEntryClass))

typedef struct _TagsSidebarEntry TagsSidebarEntry;
typedef struct _TagsSidebarEntryClass TagsSidebarEntryClass;

#define TYPE_DATA_COLLECTION (data_collection_get_type ())
#define DATA_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_COLLECTION, DataCollection))
#define DATA_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_COLLECTION, DataCollectionClass))
#define IS_DATA_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_COLLECTION))
#define IS_DATA_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_COLLECTION))
#define DATA_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_COLLECTION, DataCollectionClass))

typedef struct _DataCollection DataCollection;
typedef struct _DataCollectionClass DataCollectionClass;

#define TYPE_SOURCE_COLLECTION (source_collection_get_type ())
#define SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SOURCE_COLLECTION, SourceCollection))
#define SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SOURCE_COLLECTION, SourceCollectionClass))
#define IS_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SOURCE_COLLECTION))
#define IS_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SOURCE_COLLECTION))
#define SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SOURCE_COLLECTION, SourceCollectionClass))

typedef struct _SourceCollection SourceCollection;
typedef struct _SourceCollectionClass SourceCollectionClass;

#define TYPE_DATABASE_SOURCE_COLLECTION (database_source_collection_get_type ())
#define DATABASE_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollection))
#define DATABASE_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollectionClass))
#define IS_DATABASE_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATABASE_SOURCE_COLLECTION))
#define IS_DATABASE_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATABASE_SOURCE_COLLECTION))
#define DATABASE_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollectionClass))

typedef struct _DatabaseSourceCollection DatabaseSourceCollection;
typedef struct _DatabaseSourceCollectionClass DatabaseSourceCollectionClass;

#define TYPE_CONTAINER_SOURCE_COLLECTION (container_source_collection_get_type ())
#define CONTAINER_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CONTAINER_SOURCE_COLLECTION, ContainerSourceCollection))
#define CONTAINER_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CONTAINER_SOURCE_COLLECTION, ContainerSourceCollectionClass))
#define IS_CONTAINER_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CONTAINER_SOURCE_COLLECTION))
#define IS_CONTAINER_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CONTAINER_SOURCE_COLLECTION))
#define CONTAINER_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CONTAINER_SOURCE_COLLECTION, ContainerSourceCollectionClass))

typedef struct _ContainerSourceCollection ContainerSourceCollection;
typedef struct _ContainerSourceCollectionClass ContainerSourceCollectionClass;

#define TYPE_TAG_SOURCE_COLLECTION (tag_source_collection_get_type ())
#define TAG_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TAG_SOURCE_COLLECTION, TagSourceCollection))
#define TAG_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TAG_SOURCE_COLLECTION, TagSourceCollectionClass))
#define IS_TAG_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TAG_SOURCE_COLLECTION))
#define IS_TAG_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TAG_SOURCE_COLLECTION))
#define TAG_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TAG_SOURCE_COLLECTION, TagSourceCollectionClass))

typedef struct _TagSourceCollection TagSourceCollection;
typedef struct _TagSourceCollectionClass TagSourceCollectionClass;

#define TYPE_ALTERATION (alteration_get_type ())
#define ALTERATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ALTERATION, Alteration))
#define ALTERATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ALTERATION, AlterationClass))
#define IS_ALTERATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ALTERATION))
#define IS_ALTERATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ALTERATION))
#define ALTERATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_ALTERATION, AlterationClass))

typedef struct _Alteration Alteration;
typedef struct _AlterationClass AlterationClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define SIDEBAR_TYPE_GROUPING (sidebar_grouping_get_type ())
#define SIDEBAR_GROUPING(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_GROUPING, SidebarGrouping))
#define SIDEBAR_GROUPING_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SIDEBAR_TYPE_GROUPING, SidebarGroupingClass))
#define SIDEBAR_IS_GROUPING(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_GROUPING))
#define SIDEBAR_IS_GROUPING_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SIDEBAR_TYPE_GROUPING))
#define SIDEBAR_GROUPING_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SIDEBAR_TYPE_GROUPING, SidebarGroupingClass))

typedef struct _SidebarGrouping SidebarGrouping;
typedef struct _SidebarGroupingClass SidebarGroupingClass;

#define SIDEBAR_TYPE_HEADER (sidebar_header_get_type ())
#define SIDEBAR_HEADER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_HEADER, SidebarHeader))
#define SIDEBAR_HEADER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SIDEBAR_TYPE_HEADER, SidebarHeaderClass))
#define SIDEBAR_IS_HEADER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_HEADER))
#define SIDEBAR_IS_HEADER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SIDEBAR_TYPE_HEADER))
#define SIDEBAR_HEADER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SIDEBAR_TYPE_HEADER, SidebarHeaderClass))

typedef struct _SidebarHeader SidebarHeader;
typedef struct _SidebarHeaderClass SidebarHeaderClass;

#define TAGS_TYPE_HEADER (tags_header_get_type ())
#define TAGS_HEADER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TAGS_TYPE_HEADER, TagsHeader))
#define TAGS_HEADER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TAGS_TYPE_HEADER, TagsHeaderClass))
#define TAGS_IS_HEADER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TAGS_TYPE_HEADER))
#define TAGS_IS_HEADER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TAGS_TYPE_HEADER))
#define TAGS_HEADER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TAGS_TYPE_HEADER, TagsHeaderClass))

typedef struct _TagsHeader TagsHeader;
typedef struct _TagsHeaderClass TagsHeaderClass;

#define SIDEBAR_TYPE_ENTRY (sidebar_entry_get_type ())
#define SIDEBAR_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_ENTRY, SidebarEntry))
#define SIDEBAR_IS_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_ENTRY))
#define SIDEBAR_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_ENTRY, SidebarEntryIface))

typedef struct _SidebarEntry SidebarEntry;
typedef struct _SidebarEntryIface SidebarEntryIface;

#define SIDEBAR_TYPE_TREE (sidebar_tree_get_type ())
#define SIDEBAR_TREE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_TREE, SidebarTree))
#define SIDEBAR_TREE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SIDEBAR_TYPE_TREE, SidebarTreeClass))
#define SIDEBAR_IS_TREE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_TREE))
#define SIDEBAR_IS_TREE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SIDEBAR_TYPE_TREE))
#define SIDEBAR_TREE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SIDEBAR_TYPE_TREE, SidebarTreeClass))

typedef struct _SidebarTree SidebarTree;
typedef struct _SidebarTreeClass SidebarTreeClass;

#define SIDEBAR_BRANCH_TYPE_OPTIONS (sidebar_branch_options_get_type ())
#define _alteration_unref0(var) ((var == NULL) ? NULL : (var = (alteration_unref (var), NULL)))

#define SIDEBAR_TYPE_RENAMEABLE_ENTRY (sidebar_renameable_entry_get_type ())
#define SIDEBAR_RENAMEABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_RENAMEABLE_ENTRY, SidebarRenameableEntry))
#define SIDEBAR_IS_RENAMEABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_RENAMEABLE_ENTRY))
#define SIDEBAR_RENAMEABLE_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_RENAMEABLE_ENTRY, SidebarRenameableEntryIface))

typedef struct _SidebarRenameableEntry SidebarRenameableEntry;
typedef struct _SidebarRenameableEntryIface SidebarRenameableEntryIface;
#define _g_free0(var) (var = (g_free (var), NULL))

#define SIDEBAR_TYPE_EXPANDABLE_ENTRY (sidebar_expandable_entry_get_type ())
#define SIDEBAR_EXPANDABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_EXPANDABLE_ENTRY, SidebarExpandableEntry))
#define SIDEBAR_IS_EXPANDABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_EXPANDABLE_ENTRY))
#define SIDEBAR_EXPANDABLE_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_EXPANDABLE_ENTRY, SidebarExpandableEntryIface))

typedef struct _SidebarExpandableEntry SidebarExpandableEntry;
typedef struct _SidebarExpandableEntryIface SidebarExpandableEntryIface;
typedef struct _SidebarGroupingPrivate SidebarGroupingPrivate;

#define SIDEBAR_TYPE_EMPHASIZABLE_ENTRY (sidebar_emphasizable_entry_get_type ())
#define SIDEBAR_EMPHASIZABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_EMPHASIZABLE_ENTRY, SidebarEmphasizableEntry))
#define SIDEBAR_IS_EMPHASIZABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_EMPHASIZABLE_ENTRY))
#define SIDEBAR_EMPHASIZABLE_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_EMPHASIZABLE_ENTRY, SidebarEmphasizableEntryIface))

typedef struct _SidebarEmphasizableEntry SidebarEmphasizableEntry;
typedef struct _SidebarEmphasizableEntryIface SidebarEmphasizableEntryIface;
typedef struct _SidebarHeaderPrivate SidebarHeaderPrivate;

#define SIDEBAR_TYPE_INTERNAL_DROP_TARGET_ENTRY (sidebar_internal_drop_target_entry_get_type ())
#define SIDEBAR_INTERNAL_DROP_TARGET_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_INTERNAL_DROP_TARGET_ENTRY, SidebarInternalDropTargetEntry))
#define SIDEBAR_IS_INTERNAL_DROP_TARGET_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_INTERNAL_DROP_TARGET_ENTRY))
#define SIDEBAR_INTERNAL_DROP_TARGET_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_INTERNAL_DROP_TARGET_ENTRY, SidebarInternalDropTargetEntryIface))

typedef struct _SidebarInternalDropTargetEntry SidebarInternalDropTargetEntry;
typedef struct _SidebarInternalDropTargetEntryIface SidebarInternalDropTargetEntryIface;

#define TYPE_THUMBNAIL_SOURCE (thumbnail_source_get_type ())
#define THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSource))
#define THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))
#define IS_THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_THUMBNAIL_SOURCE))
#define IS_THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_THUMBNAIL_SOURCE))
#define THUMBNAIL_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))

typedef struct _ThumbnailSource ThumbnailSource;
typedef struct _ThumbnailSourceClass ThumbnailSourceClass;

#define TYPE_MEDIA_SOURCE (media_source_get_type ())
#define MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_SOURCE, MediaSource))
#define MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_SOURCE, MediaSourceClass))
#define IS_MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_SOURCE))
#define IS_MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_SOURCE))
#define MEDIA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_SOURCE, MediaSourceClass))

typedef struct _MediaSource MediaSource;
typedef struct _MediaSourceClass MediaSourceClass;

#define SIDEBAR_TYPE_INTERNAL_DRAG_SOURCE_ENTRY (sidebar_internal_drag_source_entry_get_type ())
#define SIDEBAR_INTERNAL_DRAG_SOURCE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_INTERNAL_DRAG_SOURCE_ENTRY, SidebarInternalDragSourceEntry))
#define SIDEBAR_IS_INTERNAL_DRAG_SOURCE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_INTERNAL_DRAG_SOURCE_ENTRY))
#define SIDEBAR_INTERNAL_DRAG_SOURCE_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_INTERNAL_DRAG_SOURCE_ENTRY, SidebarInternalDragSourceEntryIface))

typedef struct _SidebarInternalDragSourceEntry SidebarInternalDragSourceEntry;
typedef struct _SidebarInternalDragSourceEntryIface SidebarInternalDragSourceEntryIface;

#define SIDEBAR_TYPE_CONTEXTABLE (sidebar_contextable_get_type ())
#define SIDEBAR_CONTEXTABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_CONTEXTABLE, SidebarContextable))
#define SIDEBAR_IS_CONTEXTABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_CONTEXTABLE))
#define SIDEBAR_CONTEXTABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_CONTEXTABLE, SidebarContextableIface))

typedef struct _SidebarContextable SidebarContextable;
typedef struct _SidebarContextableIface SidebarContextableIface;
typedef struct _TagsHeaderPrivate TagsHeaderPrivate;

#define TYPE_APPLICATION (application_get_type ())
#define APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_APPLICATION, Application))
#define APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_APPLICATION, ApplicationClass))
#define IS_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_APPLICATION))
#define IS_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_APPLICATION))
#define APPLICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_APPLICATION, ApplicationClass))

typedef struct _Application Application;
typedef struct _ApplicationClass ApplicationClass;
#define _application_unref0(var) ((var == NULL) ? NULL : (var = (application_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define TYPE_TEXT_ENTRY_DIALOG_MEDIATOR (text_entry_dialog_mediator_get_type ())
#define TEXT_ENTRY_DIALOG_MEDIATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, TextEntryDialogMediator))
#define TEXT_ENTRY_DIALOG_MEDIATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, TextEntryDialogMediatorClass))
#define IS_TEXT_ENTRY_DIALOG_MEDIATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TEXT_ENTRY_DIALOG_MEDIATOR))
#define IS_TEXT_ENTRY_DIALOG_MEDIATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TEXT_ENTRY_DIALOG_MEDIATOR))
#define TEXT_ENTRY_DIALOG_MEDIATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, TextEntryDialogMediatorClass))

typedef struct _TextEntryDialogMediator TextEntryDialogMediator;
typedef struct _TextEntryDialogMediatorClass TextEntryDialogMediatorClass;

#define TYPE_TAGS_DIALOG (tags_dialog_get_type ())
#define TAGS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TAGS_DIALOG, TagsDialog))
#define TAGS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TAGS_DIALOG, TagsDialogClass))
#define IS_TAGS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TAGS_DIALOG))
#define IS_TAGS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TAGS_DIALOG))
#define TAGS_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TAGS_DIALOG, TagsDialogClass))

typedef struct _TagsDialog TagsDialog;
typedef struct _TagsDialogClass TagsDialogClass;

#define TYPE_ADD_TAGS_DIALOG (add_tags_dialog_get_type ())
#define ADD_TAGS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ADD_TAGS_DIALOG, AddTagsDialog))
#define ADD_TAGS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ADD_TAGS_DIALOG, AddTagsDialogClass))
#define IS_ADD_TAGS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ADD_TAGS_DIALOG))
#define IS_ADD_TAGS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ADD_TAGS_DIALOG))
#define ADD_TAGS_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_ADD_TAGS_DIALOG, AddTagsDialogClass))

typedef struct _AddTagsDialog AddTagsDialog;
typedef struct _AddTagsDialogClass AddTagsDialogClass;
#define _text_entry_dialog_mediator_unref0(var) ((var == NULL) ? NULL : (var = (text_entry_dialog_mediator_unref (var), NULL)))

#define TYPE_COMMAND_MANAGER (command_manager_get_type ())
#define COMMAND_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_COMMAND_MANAGER, CommandManager))
#define COMMAND_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_COMMAND_MANAGER, CommandManagerClass))
#define IS_COMMAND_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_COMMAND_MANAGER))
#define IS_COMMAND_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_COMMAND_MANAGER))
#define COMMAND_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_COMMAND_MANAGER, CommandManagerClass))

typedef struct _CommandManager CommandManager;
typedef struct _CommandManagerClass CommandManagerClass;

#define TYPE_COMMAND (command_get_type ())
#define COMMAND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_COMMAND, Command))
#define COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_COMMAND, CommandClass))
#define IS_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_COMMAND))
#define IS_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_COMMAND))
#define COMMAND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_COMMAND, CommandClass))

typedef struct _Command Command;
typedef struct _CommandClass CommandClass;

#define TYPE_PAGE_COMMAND (page_command_get_type ())
#define PAGE_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PAGE_COMMAND, PageCommand))
#define PAGE_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PAGE_COMMAND, PageCommandClass))
#define IS_PAGE_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PAGE_COMMAND))
#define IS_PAGE_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PAGE_COMMAND))
#define PAGE_COMMAND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PAGE_COMMAND, PageCommandClass))

typedef struct _PageCommand PageCommand;
typedef struct _PageCommandClass PageCommandClass;

#define TYPE_ADD_TAGS_COMMAND (add_tags_command_get_type ())
#define ADD_TAGS_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ADD_TAGS_COMMAND, AddTagsCommand))
#define ADD_TAGS_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ADD_TAGS_COMMAND, AddTagsCommandClass))
#define IS_ADD_TAGS_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ADD_TAGS_COMMAND))
#define IS_ADD_TAGS_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ADD_TAGS_COMMAND))
#define ADD_TAGS_COMMAND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_ADD_TAGS_COMMAND, AddTagsCommandClass))

typedef struct _AddTagsCommand AddTagsCommand;
typedef struct _AddTagsCommandClass AddTagsCommandClass;
#define _command_manager_unref0(var) ((var == NULL) ? NULL : (var = (command_manager_unref (var), NULL)))

#define TYPE_REPARENT_TAG_COMMAND (reparent_tag_command_get_type ())
#define REPARENT_TAG_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_REPARENT_TAG_COMMAND, ReparentTagCommand))
#define REPARENT_TAG_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_REPARENT_TAG_COMMAND, ReparentTagCommandClass))
#define IS_REPARENT_TAG_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_REPARENT_TAG_COMMAND))
#define IS_REPARENT_TAG_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_REPARENT_TAG_COMMAND))
#define REPARENT_TAG_COMMAND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_REPARENT_TAG_COMMAND, ReparentTagCommandClass))

typedef struct _ReparentTagCommand ReparentTagCommand;
typedef struct _ReparentTagCommandClass ReparentTagCommandClass;

#define SIDEBAR_TYPE_SELECTABLE_ENTRY (sidebar_selectable_entry_get_type ())
#define SIDEBAR_SELECTABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_SELECTABLE_ENTRY, SidebarSelectableEntry))
#define SIDEBAR_IS_SELECTABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_SELECTABLE_ENTRY))
#define SIDEBAR_SELECTABLE_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_SELECTABLE_ENTRY, SidebarSelectableEntryIface))

typedef struct _SidebarSelectableEntry SidebarSelectableEntry;
typedef struct _SidebarSelectableEntryIface SidebarSelectableEntryIface;

#define SIDEBAR_TYPE_PAGE_REPRESENTATIVE (sidebar_page_representative_get_type ())
#define SIDEBAR_PAGE_REPRESENTATIVE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_PAGE_REPRESENTATIVE, SidebarPageRepresentative))
#define SIDEBAR_IS_PAGE_REPRESENTATIVE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_PAGE_REPRESENTATIVE))
#define SIDEBAR_PAGE_REPRESENTATIVE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_PAGE_REPRESENTATIVE, SidebarPageRepresentativeIface))

typedef struct _SidebarPageRepresentative SidebarPageRepresentative;
typedef struct _SidebarPageRepresentativeIface SidebarPageRepresentativeIface;

#define TYPE_PAGE (page_get_type ())
#define PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PAGE, Page))
#define PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PAGE, PageClass))
#define IS_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PAGE))
#define IS_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PAGE))
#define PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PAGE, PageClass))

typedef struct _Page Page;
typedef struct _PageClass PageClass;
typedef struct _SidebarSimplePageEntryPrivate SidebarSimplePageEntryPrivate;

#define SIDEBAR_TYPE_DESTROYABLE_ENTRY (sidebar_destroyable_entry_get_type ())
#define SIDEBAR_DESTROYABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_DESTROYABLE_ENTRY, SidebarDestroyableEntry))
#define SIDEBAR_IS_DESTROYABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_DESTROYABLE_ENTRY))
#define SIDEBAR_DESTROYABLE_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_DESTROYABLE_ENTRY, SidebarDestroyableEntryIface))

typedef struct _SidebarDestroyableEntry SidebarDestroyableEntry;
typedef struct _SidebarDestroyableEntryIface SidebarDestroyableEntryIface;
typedef struct _TagsSidebarEntryPrivate TagsSidebarEntryPrivate;

#define TYPE_CHECKERBOARD_PAGE (checkerboard_page_get_type ())
#define CHECKERBOARD_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CHECKERBOARD_PAGE, CheckerboardPage))
#define CHECKERBOARD_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CHECKERBOARD_PAGE, CheckerboardPageClass))
#define IS_CHECKERBOARD_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CHECKERBOARD_PAGE))
#define IS_CHECKERBOARD_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CHECKERBOARD_PAGE))
#define CHECKERBOARD_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CHECKERBOARD_PAGE, CheckerboardPageClass))

typedef struct _CheckerboardPage CheckerboardPage;
typedef struct _CheckerboardPageClass CheckerboardPageClass;

#define TYPE_MEDIA_PAGE (media_page_get_type ())
#define MEDIA_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_PAGE, MediaPage))
#define MEDIA_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_PAGE, MediaPageClass))
#define IS_MEDIA_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_PAGE))
#define IS_MEDIA_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_PAGE))
#define MEDIA_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_PAGE, MediaPageClass))

typedef struct _MediaPage MediaPage;
typedef struct _MediaPageClass MediaPageClass;

#define TYPE_COLLECTION_PAGE (collection_page_get_type ())
#define COLLECTION_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_COLLECTION_PAGE, CollectionPage))
#define COLLECTION_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_COLLECTION_PAGE, CollectionPageClass))
#define IS_COLLECTION_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_COLLECTION_PAGE))
#define IS_COLLECTION_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_COLLECTION_PAGE))
#define COLLECTION_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_COLLECTION_PAGE, CollectionPageClass))

typedef struct _CollectionPage CollectionPage;
typedef struct _CollectionPageClass CollectionPageClass;

#define TYPE_TAG_PAGE (tag_page_get_type ())
#define TAG_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TAG_PAGE, TagPage))
#define TAG_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TAG_PAGE, TagPageClass))
#define IS_TAG_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TAG_PAGE))
#define IS_TAG_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TAG_PAGE))
#define TAG_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TAG_PAGE, TagPageClass))

typedef struct _TagPage TagPage;
typedef struct _TagPageClass TagPageClass;
#define _g_regex_unref0(var) ((var == NULL) ? NULL : (var = (g_regex_unref (var), NULL)))

#define TYPE_SIMPLE_PROXYABLE_COMMAND (simple_proxyable_command_get_type ())
#define SIMPLE_PROXYABLE_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SIMPLE_PROXYABLE_COMMAND, SimpleProxyableCommand))
#define SIMPLE_PROXYABLE_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SIMPLE_PROXYABLE_COMMAND, SimpleProxyableCommandClass))
#define IS_SIMPLE_PROXYABLE_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SIMPLE_PROXYABLE_COMMAND))
#define IS_SIMPLE_PROXYABLE_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SIMPLE_PROXYABLE_COMMAND))
#define SIMPLE_PROXYABLE_COMMAND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SIMPLE_PROXYABLE_COMMAND, SimpleProxyableCommandClass))

typedef struct _SimpleProxyableCommand SimpleProxyableCommand;
typedef struct _SimpleProxyableCommandClass SimpleProxyableCommandClass;

#define TYPE_RENAME_TAG_COMMAND (rename_tag_command_get_type ())
#define RENAME_TAG_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_RENAME_TAG_COMMAND, RenameTagCommand))
#define RENAME_TAG_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_RENAME_TAG_COMMAND, RenameTagCommandClass))
#define IS_RENAME_TAG_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_RENAME_TAG_COMMAND))
#define IS_RENAME_TAG_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_RENAME_TAG_COMMAND))
#define RENAME_TAG_COMMAND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_RENAME_TAG_COMMAND, RenameTagCommandClass))

typedef struct _RenameTagCommand RenameTagCommand;
typedef struct _RenameTagCommandClass RenameTagCommandClass;

#define TYPE_DELETE_TAG_COMMAND (delete_tag_command_get_type ())
#define DELETE_TAG_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DELETE_TAG_COMMAND, DeleteTagCommand))
#define DELETE_TAG_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DELETE_TAG_COMMAND, DeleteTagCommandClass))
#define IS_DELETE_TAG_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DELETE_TAG_COMMAND))
#define IS_DELETE_TAG_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DELETE_TAG_COMMAND))
#define DELETE_TAG_COMMAND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DELETE_TAG_COMMAND, DeleteTagCommandClass))

typedef struct _DeleteTagCommand DeleteTagCommand;
typedef struct _DeleteTagCommandClass DeleteTagCommandClass;

#define TYPE_TAG_UNTAG_PHOTOS_COMMAND (tag_untag_photos_command_get_type ())
#define TAG_UNTAG_PHOTOS_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TAG_UNTAG_PHOTOS_COMMAND, TagUntagPhotosCommand))
#define TAG_UNTAG_PHOTOS_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TAG_UNTAG_PHOTOS_COMMAND, TagUntagPhotosCommandClass))
#define IS_TAG_UNTAG_PHOTOS_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TAG_UNTAG_PHOTOS_COMMAND))
#define IS_TAG_UNTAG_PHOTOS_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TAG_UNTAG_PHOTOS_COMMAND))
#define TAG_UNTAG_PHOTOS_COMMAND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TAG_UNTAG_PHOTOS_COMMAND, TagUntagPhotosCommandClass))

typedef struct _TagUntagPhotosCommand TagUntagPhotosCommand;
typedef struct _TagUntagPhotosCommandClass TagUntagPhotosCommandClass;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _SidebarBranch {
	GObject parent_instance;
	SidebarBranchPrivate * priv;
};

struct _SidebarBranchClass {
	GObjectClass parent_class;
};

struct _TagsBranch {
	SidebarBranch parent_instance;
	TagsBranchPrivate * priv;
};

struct _TagsBranchClass {
	SidebarBranchClass parent_class;
};

struct _TagsBranchPrivate {
	GeeHashMap* entry_map;
};

struct _SidebarEntryIface {
	GTypeInterface parent_iface;
	gchar* (*get_sidebar_name) (SidebarEntry* self);
	gchar* (*get_sidebar_tooltip) (SidebarEntry* self);
	gchar* (*get_sidebar_icon) (SidebarEntry* self);
	gchar* (*to_string) (SidebarEntry* self);
	void (*grafted) (SidebarEntry* self, SidebarTree* tree);
	void (*pruned) (SidebarEntry* self, SidebarTree* tree);
};

typedef enum  {
	SIDEBAR_BRANCH_OPTIONS_NONE = 0,
	SIDEBAR_BRANCH_OPTIONS_HIDE_IF_EMPTY = 1 << 0,
	SIDEBAR_BRANCH_OPTIONS_AUTO_OPEN_ON_NEW_CHILD = 1 << 1,
	SIDEBAR_BRANCH_OPTIONS_STARTUP_EXPAND_TO_FIRST_CHILD = 1 << 2,
	SIDEBAR_BRANCH_OPTIONS_STARTUP_OPEN_GROUPING = 1 << 3
} SidebarBranchOptions;

struct _SidebarRenameableEntryIface {
	GTypeInterface parent_iface;
	void (*rename) (SidebarRenameableEntry* self, const gchar* new_name);
	gboolean (*is_user_renameable) (SidebarRenameableEntry* self);
};

struct _SidebarExpandableEntryIface {
	GTypeInterface parent_iface;
	gboolean (*expand_on_select) (SidebarExpandableEntry* self);
};

struct _SidebarGrouping {
	GObject parent_instance;
	SidebarGroupingPrivate * priv;
};

struct _SidebarGroupingClass {
	GObjectClass parent_class;
};

struct _SidebarEmphasizableEntryIface {
	GTypeInterface parent_iface;
	gboolean (*is_emphasized) (SidebarEmphasizableEntry* self);
};

struct _SidebarHeader {
	SidebarGrouping parent_instance;
	SidebarHeaderPrivate * priv;
};

struct _SidebarHeaderClass {
	SidebarGroupingClass parent_class;
};

struct _SidebarInternalDropTargetEntryIface {
	GTypeInterface parent_iface;
	gboolean (*internal_drop_received) (SidebarInternalDropTargetEntry* self, GeeList* sources);
	gboolean (*internal_drop_received_arbitrary) (SidebarInternalDropTargetEntry* self, GtkSelectionData* data);
};

struct _SidebarInternalDragSourceEntryIface {
	GTypeInterface parent_iface;
	void (*prepare_selection_data) (SidebarInternalDragSourceEntry* self, GtkSelectionData* data);
};

struct _SidebarContextableIface {
	GTypeInterface parent_iface;
	GtkMenu* (*get_sidebar_context_menu) (SidebarContextable* self, GdkEventButton* event);
};

struct _TagsHeader {
	SidebarHeader parent_instance;
	TagsHeaderPrivate * priv;
};

struct _TagsHeaderClass {
	SidebarHeaderClass parent_class;
};

struct _TagsHeaderPrivate {
	GtkBuilder* builder;
	GtkMenu* context_menu;
};

struct _SidebarSelectableEntryIface {
	GTypeInterface parent_iface;
};

struct _SidebarPageRepresentativeIface {
	GTypeInterface parent_iface;
	gboolean (*has_page) (SidebarPageRepresentative* self);
	Page* (*get_page) (SidebarPageRepresentative* self);
};

struct _SidebarSimplePageEntry {
	GObject parent_instance;
	SidebarSimplePageEntryPrivate * priv;
};

struct _SidebarSimplePageEntryClass {
	GObjectClass parent_class;
	gchar* (*get_sidebar_name) (SidebarSimplePageEntry* self);
	gchar* (*get_sidebar_tooltip) (SidebarSimplePageEntry* self);
	gchar* (*get_sidebar_icon) (SidebarSimplePageEntry* self);
	gchar* (*to_string) (SidebarSimplePageEntry* self);
	Page* (*create_page) (SidebarSimplePageEntry* self);
};

struct _SidebarDestroyableEntryIface {
	GTypeInterface parent_iface;
	void (*destroy_source) (SidebarDestroyableEntry* self);
};

struct _TagsSidebarEntry {
	SidebarSimplePageEntry parent_instance;
	TagsSidebarEntryPrivate * priv;
};

struct _TagsSidebarEntryClass {
	SidebarSimplePageEntryClass parent_class;
};

struct _TagsSidebarEntryPrivate {
	gchar* single_tag_icon;
	Tag* tag;
};


static gpointer tags_branch_parent_class = NULL;
extern TagSourceCollection* tag_global;
static gpointer tags_header_parent_class = NULL;
static SidebarInternalDropTargetEntryIface * tags_header_sidebar_internal_drop_target_entry_parent_iface = NULL;
static SidebarInternalDragSourceEntryIface * tags_header_sidebar_internal_drag_source_entry_parent_iface = NULL;
static SidebarContextableIface * tags_header_sidebar_contextable_parent_iface = NULL;
static gpointer tags_sidebar_entry_parent_class = NULL;
static SidebarRenameableEntryIface * tags_sidebar_entry_sidebar_renameable_entry_parent_iface = NULL;
static SidebarDestroyableEntryIface * tags_sidebar_entry_sidebar_destroyable_entry_parent_iface = NULL;
static SidebarInternalDropTargetEntryIface * tags_sidebar_entry_sidebar_internal_drop_target_entry_parent_iface = NULL;
static SidebarExpandableEntryIface * tags_sidebar_entry_sidebar_expandable_entry_parent_iface = NULL;
static SidebarInternalDragSourceEntryIface * tags_sidebar_entry_sidebar_internal_drag_source_entry_parent_iface = NULL;

GType sidebar_branch_get_type (void) G_GNUC_CONST;
GType tags_branch_get_type (void) G_GNUC_CONST;
GType data_object_get_type (void) G_GNUC_CONST;
GType data_source_get_type (void) G_GNUC_CONST;
GType tag_get_type (void) G_GNUC_CONST;
GType sidebar_simple_page_entry_get_type (void) G_GNUC_CONST;
GType tags_sidebar_entry_get_type (void) G_GNUC_CONST;
#define TAGS_BRANCH_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TAGS_TYPE_BRANCH, TagsBranchPrivate))
enum  {
	TAGS_BRANCH_DUMMY_PROPERTY
};
gpointer data_collection_ref (gpointer instance);
void data_collection_unref (gpointer instance);
GParamSpec* param_spec_data_collection (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_data_collection (GValue* value, gpointer v_object);
void value_take_data_collection (GValue* value, gpointer v_object);
gpointer value_get_data_collection (const GValue* value);
GType data_collection_get_type (void) G_GNUC_CONST;
GType source_collection_get_type (void) G_GNUC_CONST;
GType database_source_collection_get_type (void) G_GNUC_CONST;
GType container_source_collection_get_type (void) G_GNUC_CONST;
GType tag_source_collection_get_type (void) G_GNUC_CONST;
static void tags_branch_on_tags_added_removed (TagsBranch* self, GeeIterable* added_raw, GeeIterable* removed);
static void _tags_branch_on_tags_added_removed_data_collection_contents_altered (DataCollection* _sender, GeeIterable* added, GeeIterable* removed, gpointer self);
gpointer alteration_ref (gpointer instance);
void alteration_unref (gpointer instance);
GParamSpec* param_spec_alteration (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_alteration (GValue* value, gpointer v_object);
void value_take_alteration (GValue* value, gpointer v_object);
gpointer value_get_alteration (const GValue* value);
GType alteration_get_type (void) G_GNUC_CONST;
static void tags_branch_on_tags_altered (TagsBranch* self, GeeMap* altered);
static void _tags_branch_on_tags_altered_data_collection_items_altered (DataCollection* _sender, GeeMap* items, gpointer self);
TagsBranch* tags_branch_new (void);
TagsBranch* tags_branch_construct (GType object_type);
TagsHeader* tags_header_new (void);
TagsHeader* tags_header_construct (GType object_type);
GType sidebar_grouping_get_type (void) G_GNUC_CONST;
GType sidebar_header_get_type (void) G_GNUC_CONST;
GType tags_header_get_type (void) G_GNUC_CONST;
GType sidebar_tree_get_type (void) G_GNUC_CONST;
GType sidebar_entry_get_type (void) G_GNUC_CONST;
GType sidebar_branch_options_get_type (void) G_GNUC_CONST;
static gint tags_branch_comparator (SidebarEntry* a, SidebarEntry* b);
static gint _tags_branch_comparator_gcompare_func (gconstpointer a, gconstpointer b);
SidebarBranch* sidebar_branch_new (SidebarEntry* root, SidebarBranchOptions options, GCompareFunc default_comparator, GCompareFunc root_comparator);
SidebarBranch* sidebar_branch_construct (GType object_type, SidebarEntry* root, SidebarBranchOptions options, GCompareFunc default_comparator, GCompareFunc root_comparator);
GeeCollection* data_collection_get_all (DataCollection* self);
TagsSidebarEntry* tags_branch_get_entry_for_tag (TagsBranch* self, Tag* tag);
gboolean tags_branch_is_user_renameable (TagsBranch* self);
gint tag_compare_names (Tag* a, Tag* b);
Tag* tags_sidebar_entry_for_tag (TagsSidebarEntry* self);
static gint _tag_compare_names_gcompare_data_func (gconstpointer a, gconstpointer b, gpointer self);
Tag* tag_get_hierarchical_parent (Tag* self);
TagsSidebarEntry* tags_sidebar_entry_new (Tag* tag);
TagsSidebarEntry* tags_sidebar_entry_construct (GType object_type, Tag* tag);
void sidebar_branch_graft (SidebarBranch* self, SidebarEntry* parent, SidebarEntry* entry, GCompareFunc comparator);
SidebarEntry* sidebar_branch_get_root (SidebarBranch* self);
void sidebar_branch_prune (SidebarBranch* self, SidebarEntry* entry);
gboolean alteration_has_detail (Alteration* self, const gchar* subject, const gchar* detail);
GType sidebar_renameable_entry_get_type (void) G_GNUC_CONST;
gchar* tag_get_user_visible_name (Tag* self);
void sidebar_branch_reorder (SidebarBranch* self, SidebarEntry* entry);
static void tags_branch_finalize (GObject * obj);
GType sidebar_expandable_entry_get_type (void) G_GNUC_CONST;
GType sidebar_emphasizable_entry_get_type (void) G_GNUC_CONST;
GType thumbnail_source_get_type (void) G_GNUC_CONST;
GType media_source_get_type (void) G_GNUC_CONST;
GType sidebar_internal_drop_target_entry_get_type (void) G_GNUC_CONST;
GType sidebar_internal_drag_source_entry_get_type (void) G_GNUC_CONST;
GType sidebar_contextable_get_type (void) G_GNUC_CONST;
#define TAGS_HEADER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TAGS_TYPE_HEADER, TagsHeaderPrivate))
enum  {
	TAGS_HEADER_DUMMY_PROPERTY
};
SidebarHeader* sidebar_header_new (const gchar* name, gboolean emphasized);
SidebarHeader* sidebar_header_construct (GType object_type, const gchar* name, gboolean emphasized);
static void tags_header_setup_context_menu (TagsHeader* self);
gchar* resources_get_ui (const gchar* filename);
void app_window_error_message (const gchar* message, GtkWindow* parent);
gpointer application_ref (gpointer instance);
void application_unref (gpointer instance);
GParamSpec* param_spec_application (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_application (GValue* value, gpointer v_object);
void value_take_application (GValue* value, gpointer v_object);
gpointer value_get_application (const GValue* value);
GType application_get_type (void) G_GNUC_CONST;
Application* application_get_instance (void);
void application_panic (Application* self);
static gboolean tags_header_real_internal_drop_received (SidebarInternalDropTargetEntry* base, GeeList* media);
gpointer text_entry_dialog_mediator_ref (gpointer instance);
void text_entry_dialog_mediator_unref (gpointer instance);
GParamSpec* param_spec_text_entry_dialog_mediator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_text_entry_dialog_mediator (GValue* value, gpointer v_object);
void value_take_text_entry_dialog_mediator (GValue* value, gpointer v_object);
gpointer value_get_text_entry_dialog_mediator (const GValue* value);
GType text_entry_dialog_mediator_get_type (void) G_GNUC_CONST;
GType tags_dialog_get_type (void) G_GNUC_CONST;
GType add_tags_dialog_get_type (void) G_GNUC_CONST;
AddTagsDialog* add_tags_dialog_new (void);
AddTagsDialog* add_tags_dialog_construct (GType object_type);
gchar** add_tags_dialog_execute (AddTagsDialog* self, int* result_length1);
gpointer command_manager_ref (gpointer instance);
void command_manager_unref (gpointer instance);
GParamSpec* param_spec_command_manager (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_command_manager (GValue* value, gpointer v_object);
void value_take_command_manager (GValue* value, gpointer v_object);
gpointer value_get_command_manager (const GValue* value);
GType command_manager_get_type (void) G_GNUC_CONST;
CommandManager* app_window_get_command_manager (void);
GType command_get_type (void) G_GNUC_CONST;
void command_manager_execute (CommandManager* self, Command* command);
AddTagsCommand* add_tags_command_new (gchar** paths, int paths_length1, GeeCollection* sources);
AddTagsCommand* add_tags_command_construct (GType object_type, gchar** paths, int paths_length1, GeeCollection* sources);
GType page_command_get_type (void) G_GNUC_CONST;
GType add_tags_command_get_type (void) G_GNUC_CONST;
static gboolean tags_header_real_internal_drop_received_arbitrary (SidebarInternalDropTargetEntry* base, GtkSelectionData* data);
#define LIBRARY_WINDOW_TAG_PATH_MIME_TYPE "shotwell/tag-path"
gboolean tag_source_collection_exists (TagSourceCollection* self, const gchar* name, gboolean treat_htags_as_root);
GeeList* hierarchical_tag_utilities_enumerate_path_components (const gchar* in_path);
Tag* tag_for_path (const gchar* name);
ReparentTagCommand* reparent_tag_command_new (Tag* tag, const gchar* new_parent_path);
ReparentTagCommand* reparent_tag_command_construct (GType object_type, Tag* tag, const gchar* new_parent_path);
GType reparent_tag_command_get_type (void) G_GNUC_CONST;
static void tags_header_real_prepare_selection_data (SidebarInternalDragSourceEntry* base, GtkSelectionData* data);
static GtkMenu* tags_header_real_get_sidebar_context_menu (SidebarContextable* base, GdkEventButton* event);
static void tags_header_finalize (GObject * obj);
GType sidebar_selectable_entry_get_type (void) G_GNUC_CONST;
GType page_get_type (void) G_GNUC_CONST;
GType sidebar_page_representative_get_type (void) G_GNUC_CONST;
GType sidebar_destroyable_entry_get_type (void) G_GNUC_CONST;
#define TAGS_SIDEBAR_ENTRY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TAGS_TYPE_SIDEBAR_ENTRY, TagsSidebarEntryPrivate))
enum  {
	TAGS_SIDEBAR_ENTRY_DUMMY_PROPERTY
};
#define RESOURCES_ICON_ONE_TAG "one-tag"
SidebarSimplePageEntry* sidebar_simple_page_entry_construct (GType object_type);
void tags_sidebar_entry_init (void);
void tags_sidebar_entry_terminate (void);
static gchar* tags_sidebar_entry_real_get_sidebar_name (SidebarSimplePageEntry* base);
static gchar* tags_sidebar_entry_real_get_sidebar_icon (SidebarSimplePageEntry* base);
static Page* tags_sidebar_entry_real_create_page (SidebarSimplePageEntry* base);
TagPage* tag_page_new (Tag* tag);
TagPage* tag_page_construct (GType object_type, Tag* tag);
GType checkerboard_page_get_type (void) G_GNUC_CONST;
GType media_page_get_type (void) G_GNUC_CONST;
GType collection_page_get_type (void) G_GNUC_CONST;
GType tag_page_get_type (void) G_GNUC_CONST;
static gboolean tags_sidebar_entry_real_is_user_renameable (SidebarRenameableEntry* base);
static void tags_sidebar_entry_real_rename (SidebarRenameableEntry* base, const gchar* new_name);
gchar* tag_prep_tag_name (const gchar* name);
RenameTagCommand* rename_tag_command_new (Tag* tag, const gchar* new_name);
RenameTagCommand* rename_tag_command_construct (GType object_type, Tag* tag, const gchar* new_name);
GType simple_proxyable_command_get_type (void) G_GNUC_CONST;
GType rename_tag_command_get_type (void) G_GNUC_CONST;
static void tags_sidebar_entry_real_destroy_source (SidebarDestroyableEntry* base);
gboolean dialogs_confirm_delete_tag (Tag* tag);
DeleteTagCommand* delete_tag_command_new (Tag* tag);
DeleteTagCommand* delete_tag_command_construct (GType object_type, Tag* tag);
GType delete_tag_command_get_type (void) G_GNUC_CONST;
static gboolean tags_sidebar_entry_real_internal_drop_received (SidebarInternalDropTargetEntry* base, GeeList* media);
TagUntagPhotosCommand* tag_untag_photos_command_new (Tag* tag, GeeCollection* sources, gint count, gboolean attach);
TagUntagPhotosCommand* tag_untag_photos_command_construct (GType object_type, Tag* tag, GeeCollection* sources, gint count, gboolean attach);
GType tag_untag_photos_command_get_type (void) G_GNUC_CONST;
static gboolean tags_sidebar_entry_real_internal_drop_received_arbitrary (SidebarInternalDropTargetEntry* base, GtkSelectionData* data);
gchar* tag_get_path (Tag* self);
GeeList* hierarchical_tag_utilities_enumerate_parent_paths (const gchar* in_path);
static gboolean tags_sidebar_entry_real_expand_on_select (SidebarExpandableEntry* base);
static void tags_sidebar_entry_real_prepare_selection_data (SidebarInternalDragSourceEntry* base, GtkSelectionData* data);
static void tags_sidebar_entry_finalize (GObject * obj);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


static void _tags_branch_on_tags_added_removed_data_collection_contents_altered (DataCollection* _sender, GeeIterable* added, GeeIterable* removed, gpointer self) {
#line 26 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	tags_branch_on_tags_added_removed ((TagsBranch*) self, added, removed);
#line 831 "Branch.c"
}


static void _tags_branch_on_tags_altered_data_collection_items_altered (DataCollection* _sender, GeeMap* items, gpointer self) {
#line 27 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	tags_branch_on_tags_altered ((TagsBranch*) self, items);
#line 838 "Branch.c"
}


static gint _tags_branch_comparator_gcompare_func (gconstpointer a, gconstpointer b) {
	gint result;
	result = tags_branch_comparator ((SidebarEntry*) a, (SidebarEntry*) b);
#line 11 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	return result;
#line 847 "Branch.c"
}


TagsBranch* tags_branch_construct (GType object_type) {
	TagsBranch * self = NULL;
	TagsHeader* _tmp0_;
	TagsHeader* _tmp1_;
	TagSourceCollection* _tmp2_;
	GeeCollection* _tmp3_;
	GeeCollection* _tmp4_;
	TagSourceCollection* _tmp5_;
	TagSourceCollection* _tmp6_;
#line 11 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp0_ = tags_header_new ();
#line 11 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp1_ = _tmp0_;
#line 11 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	self = (TagsBranch*) sidebar_branch_construct (object_type, G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, SIDEBAR_TYPE_ENTRY, SidebarEntry), (SIDEBAR_BRANCH_OPTIONS_HIDE_IF_EMPTY | SIDEBAR_BRANCH_OPTIONS_AUTO_OPEN_ON_NEW_CHILD) | SIDEBAR_BRANCH_OPTIONS_STARTUP_OPEN_GROUPING, _tags_branch_comparator_gcompare_func, NULL);
#line 11 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_g_object_unref0 (_tmp1_);
#line 18 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp2_ = tag_global;
#line 18 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp3_ = data_collection_get_all (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, TYPE_DATA_COLLECTION, DataCollection));
#line 18 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp4_ = _tmp3_;
#line 18 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	tags_branch_on_tags_added_removed (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, GEE_TYPE_ITERABLE, GeeIterable), NULL);
#line 18 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_g_object_unref0 (_tmp4_);
#line 21 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp5_ = tag_global;
#line 21 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, TYPE_DATA_COLLECTION, DataCollection), "contents-altered", (GCallback) _tags_branch_on_tags_added_removed_data_collection_contents_altered, self, 0);
#line 22 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp6_ = tag_global;
#line 22 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, TYPE_DATA_COLLECTION, DataCollection), "items-altered", (GCallback) _tags_branch_on_tags_altered_data_collection_items_altered, self, 0);
#line 10 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	return self;
#line 888 "Branch.c"
}


TagsBranch* tags_branch_new (void) {
#line 10 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	return tags_branch_construct (TAGS_TYPE_BRANCH);
#line 895 "Branch.c"
}


TagsSidebarEntry* tags_branch_get_entry_for_tag (TagsBranch* self, Tag* tag) {
	TagsSidebarEntry* result = NULL;
	GeeHashMap* _tmp0_;
	Tag* _tmp1_;
	gpointer _tmp2_;
#line 30 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	g_return_val_if_fail (TAGS_IS_BRANCH (self), NULL);
#line 30 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	g_return_val_if_fail (IS_TAG (tag), NULL);
#line 31 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp0_ = self->priv->entry_map;
#line 31 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp1_ = tag;
#line 31 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp2_ = gee_abstract_map_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp1_);
#line 31 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	result = (TagsSidebarEntry*) _tmp2_;
#line 31 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	return result;
#line 918 "Branch.c"
}


gboolean tags_branch_is_user_renameable (TagsBranch* self) {
	gboolean result = FALSE;
#line 34 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	g_return_val_if_fail (TAGS_IS_BRANCH (self), FALSE);
#line 35 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	result = TRUE;
#line 35 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	return result;
#line 930 "Branch.c"
}


static gint tags_branch_comparator (SidebarEntry* a, SidebarEntry* b) {
	gint result = 0;
	SidebarEntry* _tmp0_;
	SidebarEntry* _tmp1_;
	SidebarEntry* _tmp2_;
	Tag* _tmp3_;
	Tag* _tmp4_;
	SidebarEntry* _tmp5_;
	Tag* _tmp6_;
	Tag* _tmp7_;
	gint _tmp8_;
	gint _tmp9_;
#line 38 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	g_return_val_if_fail (SIDEBAR_IS_ENTRY (a), 0);
#line 38 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	g_return_val_if_fail (SIDEBAR_IS_ENTRY (b), 0);
#line 39 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp0_ = a;
#line 39 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp1_ = b;
#line 39 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	if (_tmp0_ == _tmp1_) {
#line 40 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		result = 0;
#line 40 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		return result;
#line 960 "Branch.c"
	}
#line 42 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp2_ = a;
#line 42 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp3_ = tags_sidebar_entry_for_tag (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, TAGS_TYPE_SIDEBAR_ENTRY, TagsSidebarEntry));
#line 42 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp4_ = _tmp3_;
#line 42 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp5_ = b;
#line 42 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp6_ = tags_sidebar_entry_for_tag (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, TAGS_TYPE_SIDEBAR_ENTRY, TagsSidebarEntry));
#line 42 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp7_ = _tmp6_;
#line 42 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp8_ = tag_compare_names (_tmp4_, _tmp7_);
#line 42 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp9_ = _tmp8_;
#line 42 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_g_object_unref0 (_tmp7_);
#line 42 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_g_object_unref0 (_tmp4_);
#line 42 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	result = _tmp9_;
#line 42 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	return result;
#line 986 "Branch.c"
}


static gint _tag_compare_names_gcompare_data_func (gconstpointer a, gconstpointer b, gpointer self) {
	gint result;
	result = tag_compare_names ((Tag*) a, (Tag*) b);
#line 57 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	return result;
#line 995 "Branch.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 59 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	return self ? g_object_ref (self) : NULL;
#line 1002 "Branch.c"
}


static void tags_branch_on_tags_added_removed (TagsBranch* self, GeeIterable* added_raw, GeeIterable* removed) {
	Tag* restore_point = NULL;
	GeeIterable* _tmp0_;
	GeeIterable* _tmp49_;
#line 46 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	g_return_if_fail (TAGS_IS_BRANCH (self));
#line 46 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	g_return_if_fail ((added_raw == NULL) || GEE_IS_ITERABLE (added_raw));
#line 46 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	g_return_if_fail ((removed == NULL) || GEE_IS_ITERABLE (removed));
#line 51 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	restore_point = NULL;
#line 53 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp0_ = added_raw;
#line 53 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	if (_tmp0_ != NULL) {
#line 1022 "Branch.c"
		GeeSortedSet* added = NULL;
		GeeTreeSet* _tmp1_;
#line 57 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp1_ = gee_tree_set_new (TYPE_TAG, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, _tag_compare_names_gcompare_data_func, NULL, NULL);
#line 57 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		added = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GEE_TYPE_SORTED_SET, GeeSortedSet);
#line 1029 "Branch.c"
		{
			GeeIterator* _object_it = NULL;
			GeeIterable* _tmp2_;
			GeeIterator* _tmp3_;
#line 58 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp2_ = added_raw;
#line 58 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp3_ = gee_iterable_iterator (_tmp2_);
#line 58 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_object_it = _tmp3_;
#line 58 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			while (TRUE) {
#line 1042 "Branch.c"
				GeeIterator* _tmp4_;
				gboolean _tmp5_;
				DataObject* object = NULL;
				GeeIterator* _tmp6_;
				gpointer _tmp7_;
				Tag* tag = NULL;
				DataObject* _tmp8_;
				Tag* _tmp9_;
				GeeSortedSet* _tmp10_;
				Tag* _tmp11_;
#line 58 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp4_ = _object_it;
#line 58 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp5_ = gee_iterator_next (_tmp4_);
#line 58 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				if (!_tmp5_) {
#line 58 "/home/jens/Source/shotwell/src/tags/Branch.vala"
					break;
#line 1061 "Branch.c"
				}
#line 58 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp6_ = _object_it;
#line 58 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp7_ = gee_iterator_get (_tmp6_);
#line 58 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				object = (DataObject*) _tmp7_;
#line 59 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp8_ = object;
#line 59 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp9_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, TYPE_TAG, Tag));
#line 59 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				tag = _tmp9_;
#line 60 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp10_ = added;
#line 60 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp11_ = tag;
#line 60 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				gee_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, GEE_TYPE_COLLECTION, GeeCollection), _tmp11_);
#line 58 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_g_object_unref0 (tag);
#line 58 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_g_object_unref0 (object);
#line 1085 "Branch.c"
			}
#line 58 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_g_object_unref0 (_object_it);
#line 1089 "Branch.c"
		}
		{
			GeeIterator* _tag_it = NULL;
			GeeSortedSet* _tmp12_;
			GeeIterator* _tmp13_;
#line 63 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp12_ = added;
#line 63 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp13_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, GEE_TYPE_ITERABLE, GeeIterable));
#line 63 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tag_it = _tmp13_;
#line 63 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			while (TRUE) {
#line 1103 "Branch.c"
				GeeIterator* _tmp14_;
				gboolean _tmp15_;
				Tag* tag = NULL;
				GeeIterator* _tmp16_;
				gpointer _tmp17_;
				Tag* parent_tag = NULL;
				Tag* _tmp18_;
				Tag* _tmp19_;
				TagsSidebarEntry* entry = NULL;
				Tag* _tmp31_;
				TagsSidebarEntry* _tmp32_;
				GeeHashMap* _tmp33_;
				Tag* _tmp34_;
				TagsSidebarEntry* _tmp35_;
				Tag* _tmp36_;
				Tag* _tmp37_;
				Tag* _tmp38_;
				Tag* _tmp47_;
				Tag* _tmp48_;
#line 63 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp14_ = _tag_it;
#line 63 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp15_ = gee_iterator_next (_tmp14_);
#line 63 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				if (!_tmp15_) {
#line 63 "/home/jens/Source/shotwell/src/tags/Branch.vala"
					break;
#line 1131 "Branch.c"
				}
#line 63 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp16_ = _tag_it;
#line 63 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp17_ = gee_iterator_get (_tmp16_);
#line 63 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				tag = (Tag*) _tmp17_;
#line 66 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp18_ = tag;
#line 66 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp19_ = tag_get_hierarchical_parent (_tmp18_);
#line 66 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				parent_tag = _tmp19_;
#line 67 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				while (TRUE) {
#line 1147 "Branch.c"
					Tag* _tmp20_;
					GeeHashMap* _tmp21_;
					Tag* _tmp22_;
					gboolean _tmp23_;
					Tag* _tmp29_;
					Tag* _tmp30_;
#line 67 "/home/jens/Source/shotwell/src/tags/Branch.vala"
					_tmp20_ = parent_tag;
#line 67 "/home/jens/Source/shotwell/src/tags/Branch.vala"
					if (!(_tmp20_ != NULL)) {
#line 67 "/home/jens/Source/shotwell/src/tags/Branch.vala"
						break;
#line 1160 "Branch.c"
					}
#line 68 "/home/jens/Source/shotwell/src/tags/Branch.vala"
					_tmp21_ = self->priv->entry_map;
#line 68 "/home/jens/Source/shotwell/src/tags/Branch.vala"
					_tmp22_ = parent_tag;
#line 68 "/home/jens/Source/shotwell/src/tags/Branch.vala"
					_tmp23_ = gee_abstract_map_has_key (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp22_);
#line 68 "/home/jens/Source/shotwell/src/tags/Branch.vala"
					if (!_tmp23_) {
#line 1170 "Branch.c"
						TagsSidebarEntry* parent_entry = NULL;
						Tag* _tmp24_;
						TagsSidebarEntry* _tmp25_;
						GeeHashMap* _tmp26_;
						Tag* _tmp27_;
						TagsSidebarEntry* _tmp28_;
#line 69 "/home/jens/Source/shotwell/src/tags/Branch.vala"
						_tmp24_ = parent_tag;
#line 69 "/home/jens/Source/shotwell/src/tags/Branch.vala"
						_tmp25_ = tags_sidebar_entry_new (_tmp24_);
#line 69 "/home/jens/Source/shotwell/src/tags/Branch.vala"
						parent_entry = _tmp25_;
#line 70 "/home/jens/Source/shotwell/src/tags/Branch.vala"
						_tmp26_ = self->priv->entry_map;
#line 70 "/home/jens/Source/shotwell/src/tags/Branch.vala"
						_tmp27_ = parent_tag;
#line 70 "/home/jens/Source/shotwell/src/tags/Branch.vala"
						_tmp28_ = parent_entry;
#line 70 "/home/jens/Source/shotwell/src/tags/Branch.vala"
						gee_abstract_map_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp26_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp27_, _tmp28_);
#line 68 "/home/jens/Source/shotwell/src/tags/Branch.vala"
						_g_object_unref0 (parent_entry);
#line 1193 "Branch.c"
					}
#line 73 "/home/jens/Source/shotwell/src/tags/Branch.vala"
					_tmp29_ = parent_tag;
#line 73 "/home/jens/Source/shotwell/src/tags/Branch.vala"
					_tmp30_ = tag_get_hierarchical_parent (_tmp29_);
#line 73 "/home/jens/Source/shotwell/src/tags/Branch.vala"
					_g_object_unref0 (parent_tag);
#line 73 "/home/jens/Source/shotwell/src/tags/Branch.vala"
					parent_tag = _tmp30_;
#line 1203 "Branch.c"
				}
#line 77 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp31_ = tag;
#line 77 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp32_ = tags_sidebar_entry_new (_tmp31_);
#line 77 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				entry = _tmp32_;
#line 78 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp33_ = self->priv->entry_map;
#line 78 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp34_ = tag;
#line 78 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp35_ = entry;
#line 78 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				gee_abstract_map_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp33_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp34_, _tmp35_);
#line 80 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp36_ = tag;
#line 80 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp37_ = tag_get_hierarchical_parent (_tmp36_);
#line 80 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_g_object_unref0 (parent_tag);
#line 80 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				parent_tag = _tmp37_;
#line 81 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp38_ = parent_tag;
#line 81 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				if (_tmp38_ != NULL) {
#line 1231 "Branch.c"
					TagsSidebarEntry* parent_entry = NULL;
					GeeHashMap* _tmp39_;
					Tag* _tmp40_;
					gpointer _tmp41_;
					TagsSidebarEntry* _tmp42_;
					TagsSidebarEntry* _tmp43_;
#line 82 "/home/jens/Source/shotwell/src/tags/Branch.vala"
					_tmp39_ = self->priv->entry_map;
#line 82 "/home/jens/Source/shotwell/src/tags/Branch.vala"
					_tmp40_ = parent_tag;
#line 82 "/home/jens/Source/shotwell/src/tags/Branch.vala"
					_tmp41_ = gee_abstract_map_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp39_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp40_);
#line 82 "/home/jens/Source/shotwell/src/tags/Branch.vala"
					parent_entry = (TagsSidebarEntry*) _tmp41_;
#line 83 "/home/jens/Source/shotwell/src/tags/Branch.vala"
					_tmp42_ = parent_entry;
#line 83 "/home/jens/Source/shotwell/src/tags/Branch.vala"
					_tmp43_ = entry;
#line 83 "/home/jens/Source/shotwell/src/tags/Branch.vala"
					sidebar_branch_graft (G_TYPE_CHECK_INSTANCE_CAST (self, SIDEBAR_TYPE_BRANCH, SidebarBranch), G_TYPE_CHECK_INSTANCE_CAST (_tmp42_, SIDEBAR_TYPE_ENTRY, SidebarEntry), G_TYPE_CHECK_INSTANCE_CAST (_tmp43_, SIDEBAR_TYPE_ENTRY, SidebarEntry), NULL);
#line 81 "/home/jens/Source/shotwell/src/tags/Branch.vala"
					_g_object_unref0 (parent_entry);
#line 1254 "Branch.c"
				} else {
					SidebarEntry* _tmp44_;
					SidebarEntry* _tmp45_;
					TagsSidebarEntry* _tmp46_;
#line 85 "/home/jens/Source/shotwell/src/tags/Branch.vala"
					_tmp44_ = sidebar_branch_get_root (G_TYPE_CHECK_INSTANCE_CAST (self, SIDEBAR_TYPE_BRANCH, SidebarBranch));
#line 85 "/home/jens/Source/shotwell/src/tags/Branch.vala"
					_tmp45_ = _tmp44_;
#line 85 "/home/jens/Source/shotwell/src/tags/Branch.vala"
					_tmp46_ = entry;
#line 85 "/home/jens/Source/shotwell/src/tags/Branch.vala"
					sidebar_branch_graft (G_TYPE_CHECK_INSTANCE_CAST (self, SIDEBAR_TYPE_BRANCH, SidebarBranch), _tmp45_, G_TYPE_CHECK_INSTANCE_CAST (_tmp46_, SIDEBAR_TYPE_ENTRY, SidebarEntry), NULL);
#line 85 "/home/jens/Source/shotwell/src/tags/Branch.vala"
					_g_object_unref0 (_tmp45_);
#line 1269 "Branch.c"
				}
#line 90 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp47_ = tag;
#line 90 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp48_ = _g_object_ref0 (_tmp47_);
#line 90 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_g_object_unref0 (restore_point);
#line 90 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				restore_point = _tmp48_;
#line 63 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_g_object_unref0 (entry);
#line 63 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_g_object_unref0 (parent_tag);
#line 63 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_g_object_unref0 (tag);
#line 1285 "Branch.c"
			}
#line 63 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_g_object_unref0 (_tag_it);
#line 1289 "Branch.c"
		}
#line 53 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_g_object_unref0 (added);
#line 1293 "Branch.c"
	}
#line 94 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp49_ = removed;
#line 94 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	if (_tmp49_ != NULL) {
#line 1299 "Branch.c"
		{
			GeeIterator* _object_it = NULL;
			GeeIterable* _tmp50_;
			GeeIterator* _tmp51_;
#line 95 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp50_ = removed;
#line 95 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp51_ = gee_iterable_iterator (_tmp50_);
#line 95 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_object_it = _tmp51_;
#line 95 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			while (TRUE) {
#line 1312 "Branch.c"
				GeeIterator* _tmp52_;
				gboolean _tmp53_;
				DataObject* object = NULL;
				GeeIterator* _tmp54_;
				gpointer _tmp55_;
				Tag* tag = NULL;
				DataObject* _tmp56_;
				Tag* _tmp57_;
				TagsSidebarEntry* entry = NULL;
				GeeHashMap* _tmp58_;
				Tag* _tmp59_;
				gpointer _tmp60_;
				TagsSidebarEntry* _tmp61_;
				gboolean is_removed = FALSE;
				GeeHashMap* _tmp62_;
				Tag* _tmp63_;
				gboolean _tmp64_;
				gboolean _tmp65_;
				TagsSidebarEntry* _tmp66_;
#line 95 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp52_ = _object_it;
#line 95 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp53_ = gee_iterator_next (_tmp52_);
#line 95 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				if (!_tmp53_) {
#line 95 "/home/jens/Source/shotwell/src/tags/Branch.vala"
					break;
#line 1340 "Branch.c"
				}
#line 95 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp54_ = _object_it;
#line 95 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp55_ = gee_iterator_get (_tmp54_);
#line 95 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				object = (DataObject*) _tmp55_;
#line 96 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp56_ = object;
#line 96 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp57_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp56_, TYPE_TAG, Tag));
#line 96 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				tag = _tmp57_;
#line 98 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp58_ = self->priv->entry_map;
#line 98 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp59_ = tag;
#line 98 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp60_ = gee_abstract_map_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp58_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp59_);
#line 98 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				entry = (TagsSidebarEntry*) _tmp60_;
#line 99 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp61_ = entry;
#line 99 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_vala_assert (_tmp61_ != NULL, "entry != null");
#line 101 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp62_ = self->priv->entry_map;
#line 101 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp63_ = tag;
#line 101 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp64_ = gee_abstract_map_unset (G_TYPE_CHECK_INSTANCE_CAST (_tmp62_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp63_, NULL);
#line 101 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				is_removed = _tmp64_;
#line 102 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp65_ = is_removed;
#line 102 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_vala_assert (_tmp65_, "is_removed");
#line 104 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp66_ = entry;
#line 104 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				sidebar_branch_prune (G_TYPE_CHECK_INSTANCE_CAST (self, SIDEBAR_TYPE_BRANCH, SidebarBranch), G_TYPE_CHECK_INSTANCE_CAST (_tmp66_, SIDEBAR_TYPE_ENTRY, SidebarEntry));
#line 95 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_g_object_unref0 (entry);
#line 95 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_g_object_unref0 (tag);
#line 95 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_g_object_unref0 (object);
#line 1388 "Branch.c"
			}
#line 95 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_g_object_unref0 (_object_it);
#line 1392 "Branch.c"
		}
	}
#line 46 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_g_object_unref0 (restore_point);
#line 1397 "Branch.c"
}


static void tags_branch_on_tags_altered (TagsBranch* self, GeeMap* altered) {
#line 109 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	g_return_if_fail (TAGS_IS_BRANCH (self));
#line 109 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	g_return_if_fail (GEE_IS_MAP (altered));
#line 1406 "Branch.c"
	{
		GeeIterator* _object_it = NULL;
		GeeMap* _tmp0_;
		GeeSet* _tmp1_;
		GeeSet* _tmp2_;
		GeeSet* _tmp3_;
		GeeIterator* _tmp4_;
		GeeIterator* _tmp5_;
#line 110 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp0_ = altered;
#line 110 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp1_ = gee_map_get_keys (_tmp0_);
#line 110 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp2_ = _tmp1_;
#line 110 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp3_ = _tmp2_;
#line 110 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp4_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_ITERABLE, GeeIterable));
#line 110 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp5_ = _tmp4_;
#line 110 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_g_object_unref0 (_tmp3_);
#line 110 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_object_it = _tmp5_;
#line 110 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		while (TRUE) {
#line 1433 "Branch.c"
			GeeIterator* _tmp6_;
			gboolean _tmp7_;
			DataObject* object = NULL;
			GeeIterator* _tmp8_;
			gpointer _tmp9_;
			GeeMap* _tmp10_;
			DataObject* _tmp11_;
			gpointer _tmp12_;
			Alteration* _tmp13_;
			gboolean _tmp14_;
			gboolean _tmp15_;
			Tag* tag = NULL;
			DataObject* _tmp16_;
			Tag* _tmp17_;
			TagsSidebarEntry* entry = NULL;
			GeeHashMap* _tmp18_;
			Tag* _tmp19_;
			gpointer _tmp20_;
			TagsSidebarEntry* _tmp21_;
			TagsSidebarEntry* _tmp22_;
			Tag* _tmp23_;
			gchar* _tmp24_;
			gchar* _tmp25_;
			TagsSidebarEntry* _tmp26_;
			Tag* _tmp27_;
			gchar* _tmp28_;
			gchar* _tmp29_;
			TagsSidebarEntry* _tmp30_;
#line 110 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp6_ = _object_it;
#line 110 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 110 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			if (!_tmp7_) {
#line 110 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				break;
#line 1470 "Branch.c"
			}
#line 110 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp8_ = _object_it;
#line 110 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 110 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			object = (DataObject*) _tmp9_;
#line 111 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp10_ = altered;
#line 111 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp11_ = object;
#line 111 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp12_ = gee_map_get (_tmp10_, _tmp11_);
#line 111 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp13_ = (Alteration*) _tmp12_;
#line 111 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp14_ = alteration_has_detail (_tmp13_, "metadata", "name");
#line 111 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp15_ = !_tmp14_;
#line 111 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_alteration_unref0 (_tmp13_);
#line 111 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			if (_tmp15_) {
#line 112 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_g_object_unref0 (object);
#line 112 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				continue;
#line 1498 "Branch.c"
			}
#line 114 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp16_ = object;
#line 114 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp17_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, TYPE_TAG, Tag));
#line 114 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			tag = _tmp17_;
#line 115 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp18_ = self->priv->entry_map;
#line 115 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp19_ = tag;
#line 115 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp20_ = gee_abstract_map_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp19_);
#line 115 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			entry = (TagsSidebarEntry*) _tmp20_;
#line 116 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp21_ = entry;
#line 116 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_vala_assert (_tmp21_ != NULL, "entry != null");
#line 118 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp22_ = entry;
#line 118 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp23_ = tag;
#line 118 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp24_ = tag_get_user_visible_name (_tmp23_);
#line 118 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp25_ = _tmp24_;
#line 118 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			g_signal_emit_by_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, SIDEBAR_TYPE_RENAMEABLE_ENTRY, SidebarRenameableEntry), "sidebar-name-changed", _tmp25_);
#line 118 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_g_free0 (_tmp25_);
#line 119 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp26_ = entry;
#line 119 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp27_ = tag;
#line 119 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp28_ = tag_get_user_visible_name (_tmp27_);
#line 119 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp29_ = _tmp28_;
#line 119 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			g_signal_emit_by_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp26_, SIDEBAR_TYPE_ENTRY, SidebarEntry), "sidebar-tooltip-changed", _tmp29_);
#line 119 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_g_free0 (_tmp29_);
#line 120 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp30_ = entry;
#line 120 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			sidebar_branch_reorder (G_TYPE_CHECK_INSTANCE_CAST (self, SIDEBAR_TYPE_BRANCH, SidebarBranch), G_TYPE_CHECK_INSTANCE_CAST (_tmp30_, SIDEBAR_TYPE_ENTRY, SidebarEntry));
#line 110 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_g_object_unref0 (entry);
#line 110 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_g_object_unref0 (tag);
#line 110 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_g_object_unref0 (object);
#line 1552 "Branch.c"
		}
#line 110 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_g_object_unref0 (_object_it);
#line 1556 "Branch.c"
	}
}


static void tags_branch_class_init (TagsBranchClass * klass) {
#line 7 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	tags_branch_parent_class = g_type_class_peek_parent (klass);
#line 7 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	g_type_class_add_private (klass, sizeof (TagsBranchPrivate));
#line 7 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	G_OBJECT_CLASS (klass)->finalize = tags_branch_finalize;
#line 1568 "Branch.c"
}


static void tags_branch_instance_init (TagsBranch * self) {
	GeeHashMap* _tmp0_;
#line 7 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	self->priv = TAGS_BRANCH_GET_PRIVATE (self);
#line 8 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp0_ = gee_hash_map_new (TYPE_TAG, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, TAGS_TYPE_SIDEBAR_ENTRY, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 8 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	self->priv->entry_map = _tmp0_;
#line 1580 "Branch.c"
}


static void tags_branch_finalize (GObject * obj) {
	TagsBranch * self;
	TagSourceCollection* _tmp0_;
	guint _tmp1_;
	TagSourceCollection* _tmp2_;
	guint _tmp3_;
#line 7 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TAGS_TYPE_BRANCH, TagsBranch);
#line 26 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp0_ = tag_global;
#line 26 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	g_signal_parse_name ("contents-altered", TYPE_DATA_COLLECTION, &_tmp1_, NULL, FALSE);
#line 26 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_DATA_COLLECTION, DataCollection), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _tags_branch_on_tags_added_removed_data_collection_contents_altered, self);
#line 27 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp2_ = tag_global;
#line 27 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	g_signal_parse_name ("items-altered", TYPE_DATA_COLLECTION, &_tmp3_, NULL, FALSE);
#line 27 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, TYPE_DATA_COLLECTION, DataCollection), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _tags_branch_on_tags_altered_data_collection_items_altered, self);
#line 8 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_g_object_unref0 (self->priv->entry_map);
#line 7 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	G_OBJECT_CLASS (tags_branch_parent_class)->finalize (obj);
#line 1608 "Branch.c"
}


GType tags_branch_get_type (void) {
	static volatile gsize tags_branch_type_id__volatile = 0;
	if (g_once_init_enter (&tags_branch_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (TagsBranchClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tags_branch_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TagsBranch), 0, (GInstanceInitFunc) tags_branch_instance_init, NULL };
		GType tags_branch_type_id;
		tags_branch_type_id = g_type_register_static (SIDEBAR_TYPE_BRANCH, "TagsBranch", &g_define_type_info, 0);
		g_once_init_leave (&tags_branch_type_id__volatile, tags_branch_type_id);
	}
	return tags_branch_type_id__volatile;
}


TagsHeader* tags_header_construct (GType object_type) {
	TagsHeader * self = NULL;
#line 131 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	self = (TagsHeader*) sidebar_header_construct (object_type, _ ("Tags"), TRUE);
#line 132 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	tags_header_setup_context_menu (self);
#line 130 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	return self;
#line 1632 "Branch.c"
}


TagsHeader* tags_header_new (void) {
#line 130 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	return tags_header_construct (TAGS_TYPE_HEADER);
#line 1639 "Branch.c"
}


static void tags_header_setup_context_menu (TagsHeader* self) {
	GtkBuilder* _tmp0_;
	GError * _inner_error_ = NULL;
#line 135 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	g_return_if_fail (TAGS_IS_HEADER (self));
#line 136 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp0_ = gtk_builder_new ();
#line 136 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_g_object_unref0 (self->priv->builder);
#line 136 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	self->priv->builder = _tmp0_;
#line 1654 "Branch.c"
	{
		GtkBuilder* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
		GMenuModel* model = NULL;
		GtkBuilder* _tmp4_;
		GObject* _tmp5_;
		GMenuModel* _tmp6_;
		GMenuModel* _tmp7_;
		GtkMenu* _tmp8_;
#line 138 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp1_ = self->priv->builder;
#line 138 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp2_ = resources_get_ui ("tag_sidebar_context.ui");
#line 138 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp3_ = _tmp2_;
#line 138 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		gtk_builder_add_from_resource (_tmp1_, _tmp3_, &_inner_error_);
#line 138 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_g_free0 (_tmp3_);
#line 138 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1677 "Branch.c"
			goto __catch55_g_error;
		}
#line 139 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp4_ = self->priv->builder;
#line 139 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp5_ = gtk_builder_get_object (_tmp4_, "popup-menu");
#line 139 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp6_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, g_menu_model_get_type ()) ? ((GMenuModel*) _tmp5_) : NULL);
#line 139 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		model = _tmp6_;
#line 140 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp7_ = model;
#line 140 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp8_ = (GtkMenu*) gtk_menu_new_from_model (_tmp7_);
#line 140 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		g_object_ref_sink (_tmp8_);
#line 140 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_g_object_unref0 (self->priv->context_menu);
#line 140 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		self->priv->context_menu = _tmp8_;
#line 137 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_g_object_unref0 (model);
#line 1700 "Branch.c"
	}
	goto __finally55;
	__catch55_g_error:
	{
		GError* _error_ = NULL;
		GError* _tmp9_;
		const gchar* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
		Application* _tmp13_;
		Application* _tmp14_;
#line 137 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_error_ = _inner_error_;
#line 137 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_inner_error_ = NULL;
#line 142 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp9_ = _error_;
#line 142 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp10_ = _tmp9_->message;
#line 142 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp11_ = g_strdup_printf ("Error loading UI resource: %s", _tmp10_);
#line 142 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp12_ = _tmp11_;
#line 142 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		app_window_error_message (_tmp12_, NULL);
#line 142 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_g_free0 (_tmp12_);
#line 144 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp13_ = application_get_instance ();
#line 144 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp14_ = _tmp13_;
#line 144 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		application_panic (_tmp14_);
#line 144 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_application_unref0 (_tmp14_);
#line 137 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_g_error_free0 (_error_);
#line 1738 "Branch.c"
	}
	__finally55:
#line 137 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 137 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 137 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		g_clear_error (&_inner_error_);
#line 137 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		return;
#line 1749 "Branch.c"
	}
}


static gboolean tags_header_real_internal_drop_received (SidebarInternalDropTargetEntry* base, GeeList* media) {
	TagsHeader * self;
	gboolean result = FALSE;
	AddTagsDialog* dialog = NULL;
	AddTagsDialog* _tmp0_;
	gchar** names = NULL;
	AddTagsDialog* _tmp1_;
	gint _tmp2_;
	gchar** _tmp3_;
	gint names_length1;
	gint _names_size_;
	gboolean _tmp4_ = FALSE;
	gchar** _tmp5_;
	gint _tmp5__length1;
	CommandManager* _tmp7_;
	CommandManager* _tmp8_;
	gchar** _tmp9_;
	gint _tmp9__length1;
	GeeList* _tmp10_;
	AddTagsCommand* _tmp11_;
	AddTagsCommand* _tmp12_;
#line 148 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TAGS_TYPE_HEADER, TagsHeader);
#line 148 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	g_return_val_if_fail (GEE_IS_LIST (media), FALSE);
#line 149 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp0_ = add_tags_dialog_new ();
#line 149 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	dialog = _tmp0_;
#line 150 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp1_ = dialog;
#line 150 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp3_ = add_tags_dialog_execute (_tmp1_, &_tmp2_);
#line 150 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	names = _tmp3_;
#line 150 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	names_length1 = _tmp2_;
#line 150 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_names_size_ = names_length1;
#line 151 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp5_ = names;
#line 151 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp5__length1 = names_length1;
#line 151 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	if (_tmp5_ == NULL) {
#line 151 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp4_ = TRUE;
#line 1801 "Branch.c"
	} else {
		gchar** _tmp6_;
		gint _tmp6__length1;
#line 151 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp6_ = names;
#line 151 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp6__length1 = names_length1;
#line 151 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp4_ = _tmp6__length1 == 0;
#line 1811 "Branch.c"
	}
#line 151 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	if (_tmp4_) {
#line 152 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		result = FALSE;
#line 152 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		names = (_vala_array_free (names, names_length1, (GDestroyNotify) g_free), NULL);
#line 152 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_text_entry_dialog_mediator_unref0 (dialog);
#line 152 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		return result;
#line 1823 "Branch.c"
	}
#line 154 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp7_ = app_window_get_command_manager ();
#line 154 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp8_ = _tmp7_;
#line 154 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp9_ = names;
#line 154 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp9__length1 = names_length1;
#line 154 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp10_ = media;
#line 154 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp11_ = add_tags_command_new (_tmp9_, _tmp9__length1, G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, GEE_TYPE_COLLECTION, GeeCollection));
#line 154 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp12_ = _tmp11_;
#line 154 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	command_manager_execute (_tmp8_, G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, TYPE_COMMAND, Command));
#line 154 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_g_object_unref0 (_tmp12_);
#line 154 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_command_manager_unref0 (_tmp8_);
#line 156 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	result = TRUE;
#line 156 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	names = (_vala_array_free (names, names_length1, (GDestroyNotify) g_free), NULL);
#line 156 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_text_entry_dialog_mediator_unref0 (dialog);
#line 156 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	return result;
#line 1853 "Branch.c"
}


static gboolean tags_header_real_internal_drop_received_arbitrary (SidebarInternalDropTargetEntry* base, GtkSelectionData* data) {
	TagsHeader * self;
	gboolean result = FALSE;
	GtkSelectionData* _tmp0_;
	GdkAtom _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gboolean _tmp4_;
#line 159 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TAGS_TYPE_HEADER, TagsHeader);
#line 159 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	g_return_val_if_fail (data != NULL, FALSE);
#line 160 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp0_ = data;
#line 160 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp1_ = gtk_selection_data_get_data_type (_tmp0_);
#line 160 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp2_ = gdk_atom_name (_tmp1_);
#line 160 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp3_ = _tmp2_;
#line 160 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp4_ = g_strcmp0 (_tmp3_, LIBRARY_WINDOW_TAG_PATH_MIME_TYPE) == 0;
#line 160 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_g_free0 (_tmp3_);
#line 160 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	if (_tmp4_) {
#line 1883 "Branch.c"
		gchar* old_tag_path = NULL;
		GtkSelectionData* _tmp5_;
		guchar* _tmp6_;
		gchar* _tmp7_;
		TagSourceCollection* _tmp8_;
		const gchar* _tmp9_;
		gboolean _tmp10_;
		const gchar* _tmp11_;
		GeeList* _tmp12_;
		GeeList* _tmp13_;
		gint _tmp14_;
		gint _tmp15_;
		gboolean _tmp16_;
		CommandManager* _tmp17_;
		CommandManager* _tmp18_;
		const gchar* _tmp19_;
		Tag* _tmp20_;
		Tag* _tmp21_;
		ReparentTagCommand* _tmp22_;
		ReparentTagCommand* _tmp23_;
#line 161 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp5_ = data;
#line 161 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp6_ = gtk_selection_data_get_data (_tmp5_);
#line 161 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp7_ = g_strdup ((const gchar*) _tmp6_);
#line 161 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		old_tag_path = _tmp7_;
#line 162 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp8_ = tag_global;
#line 162 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp9_ = old_tag_path;
#line 162 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp10_ = tag_source_collection_exists (_tmp8_, _tmp9_, FALSE);
#line 162 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_vala_assert (_tmp10_, "Tag.global.exists(old_tag_path)");
#line 165 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp11_ = old_tag_path;
#line 165 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp12_ = hierarchical_tag_utilities_enumerate_path_components (_tmp11_);
#line 165 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp13_ = _tmp12_;
#line 165 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp14_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, GEE_TYPE_COLLECTION, GeeCollection));
#line 165 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp15_ = _tmp14_;
#line 165 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp16_ = _tmp15_ < 2;
#line 165 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_g_object_unref0 (_tmp13_);
#line 165 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		if (_tmp16_) {
#line 166 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			result = TRUE;
#line 166 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_g_free0 (old_tag_path);
#line 166 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			return result;
#line 1942 "Branch.c"
		}
#line 168 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp17_ = app_window_get_command_manager ();
#line 168 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp18_ = _tmp17_;
#line 168 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp19_ = old_tag_path;
#line 168 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp20_ = tag_for_path (_tmp19_);
#line 168 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp21_ = _tmp20_;
#line 168 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp22_ = reparent_tag_command_new (_tmp21_, "/");
#line 168 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp23_ = _tmp22_;
#line 168 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		command_manager_execute (_tmp18_, G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, TYPE_COMMAND, Command));
#line 168 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_g_object_unref0 (_tmp23_);
#line 168 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_g_object_unref0 (_tmp21_);
#line 168 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_command_manager_unref0 (_tmp18_);
#line 171 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		result = TRUE;
#line 171 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_g_free0 (old_tag_path);
#line 171 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		return result;
#line 1972 "Branch.c"
	}
#line 174 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	result = FALSE;
#line 174 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	return result;
#line 1978 "Branch.c"
}


static void tags_header_real_prepare_selection_data (SidebarInternalDragSourceEntry* base, GtkSelectionData* data) {
	TagsHeader * self;
#line 177 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TAGS_TYPE_HEADER, TagsHeader);
#line 177 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	g_return_if_fail (data != NULL);
#line 1988 "Branch.c"
}


static GtkMenu* tags_header_real_get_sidebar_context_menu (SidebarContextable* base, GdkEventButton* event) {
	TagsHeader * self;
	GtkMenu* result = NULL;
	GtkMenu* _tmp0_;
	GtkMenu* _tmp1_;
#line 181 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TAGS_TYPE_HEADER, TagsHeader);
#line 182 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp0_ = self->priv->context_menu;
#line 182 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 182 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	result = _tmp1_;
#line 182 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	return result;
#line 2007 "Branch.c"
}


static void tags_header_class_init (TagsHeaderClass * klass) {
#line 125 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	tags_header_parent_class = g_type_class_peek_parent (klass);
#line 125 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	g_type_class_add_private (klass, sizeof (TagsHeaderPrivate));
#line 125 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	G_OBJECT_CLASS (klass)->finalize = tags_header_finalize;
#line 2018 "Branch.c"
}


static void tags_header_sidebar_internal_drop_target_entry_interface_init (SidebarInternalDropTargetEntryIface * iface) {
#line 125 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	tags_header_sidebar_internal_drop_target_entry_parent_iface = g_type_interface_peek_parent (iface);
#line 125 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	iface->internal_drop_received = (gboolean (*) (SidebarInternalDropTargetEntry *, GeeList*)) tags_header_real_internal_drop_received;
#line 125 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	iface->internal_drop_received_arbitrary = (gboolean (*) (SidebarInternalDropTargetEntry *, GtkSelectionData*)) tags_header_real_internal_drop_received_arbitrary;
#line 2029 "Branch.c"
}


static void tags_header_sidebar_internal_drag_source_entry_interface_init (SidebarInternalDragSourceEntryIface * iface) {
#line 125 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	tags_header_sidebar_internal_drag_source_entry_parent_iface = g_type_interface_peek_parent (iface);
#line 125 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	iface->prepare_selection_data = (void (*) (SidebarInternalDragSourceEntry *, GtkSelectionData*)) tags_header_real_prepare_selection_data;
#line 2038 "Branch.c"
}


static void tags_header_sidebar_contextable_interface_init (SidebarContextableIface * iface) {
#line 125 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	tags_header_sidebar_contextable_parent_iface = g_type_interface_peek_parent (iface);
#line 125 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	iface->get_sidebar_context_menu = (GtkMenu* (*) (SidebarContextable *, GdkEventButton*)) tags_header_real_get_sidebar_context_menu;
#line 2047 "Branch.c"
}


static void tags_header_instance_init (TagsHeader * self) {
#line 125 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	self->priv = TAGS_HEADER_GET_PRIVATE (self);
#line 128 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	self->priv->context_menu = NULL;
#line 2056 "Branch.c"
}


static void tags_header_finalize (GObject * obj) {
	TagsHeader * self;
#line 125 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TAGS_TYPE_HEADER, TagsHeader);
#line 127 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_g_object_unref0 (self->priv->builder);
#line 128 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_g_object_unref0 (self->priv->context_menu);
#line 125 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	G_OBJECT_CLASS (tags_header_parent_class)->finalize (obj);
#line 2070 "Branch.c"
}


GType tags_header_get_type (void) {
	static volatile gsize tags_header_type_id__volatile = 0;
	if (g_once_init_enter (&tags_header_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (TagsHeaderClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tags_header_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TagsHeader), 0, (GInstanceInitFunc) tags_header_instance_init, NULL };
		static const GInterfaceInfo sidebar_internal_drop_target_entry_info = { (GInterfaceInitFunc) tags_header_sidebar_internal_drop_target_entry_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo sidebar_internal_drag_source_entry_info = { (GInterfaceInitFunc) tags_header_sidebar_internal_drag_source_entry_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo sidebar_contextable_info = { (GInterfaceInitFunc) tags_header_sidebar_contextable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType tags_header_type_id;
		tags_header_type_id = g_type_register_static (SIDEBAR_TYPE_HEADER, "TagsHeader", &g_define_type_info, 0);
		g_type_add_interface_static (tags_header_type_id, SIDEBAR_TYPE_INTERNAL_DROP_TARGET_ENTRY, &sidebar_internal_drop_target_entry_info);
		g_type_add_interface_static (tags_header_type_id, SIDEBAR_TYPE_INTERNAL_DRAG_SOURCE_ENTRY, &sidebar_internal_drag_source_entry_info);
		g_type_add_interface_static (tags_header_type_id, SIDEBAR_TYPE_CONTEXTABLE, &sidebar_contextable_info);
		g_once_init_leave (&tags_header_type_id__volatile, tags_header_type_id);
	}
	return tags_header_type_id__volatile;
}


TagsSidebarEntry* tags_sidebar_entry_construct (GType object_type, Tag* tag) {
	TagsSidebarEntry * self = NULL;
	Tag* _tmp0_;
	Tag* _tmp1_;
#line 193 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	g_return_val_if_fail (IS_TAG (tag), NULL);
#line 193 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	self = (TagsSidebarEntry*) sidebar_simple_page_entry_construct (object_type);
#line 194 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp0_ = tag;
#line 194 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 194 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_g_object_unref0 (self->priv->tag);
#line 194 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	self->priv->tag = _tmp1_;
#line 193 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	return self;
#line 2110 "Branch.c"
}


TagsSidebarEntry* tags_sidebar_entry_new (Tag* tag) {
#line 193 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	return tags_sidebar_entry_construct (TAGS_TYPE_SIDEBAR_ENTRY, tag);
#line 2117 "Branch.c"
}


void tags_sidebar_entry_init (void) {
}


void tags_sidebar_entry_terminate (void) {
}


Tag* tags_sidebar_entry_for_tag (TagsSidebarEntry* self) {
	Tag* result = NULL;
	Tag* _tmp0_;
	Tag* _tmp1_;
#line 203 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	g_return_val_if_fail (TAGS_IS_SIDEBAR_ENTRY (self), NULL);
#line 204 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp0_ = self->priv->tag;
#line 204 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 204 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	result = _tmp1_;
#line 204 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	return result;
#line 2143 "Branch.c"
}


static gchar* tags_sidebar_entry_real_get_sidebar_name (SidebarSimplePageEntry* base) {
	TagsSidebarEntry * self;
	gchar* result = NULL;
	Tag* _tmp0_;
	gchar* _tmp1_;
#line 207 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TAGS_TYPE_SIDEBAR_ENTRY, TagsSidebarEntry);
#line 208 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp0_ = self->priv->tag;
#line 208 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp1_ = tag_get_user_visible_name (_tmp0_);
#line 208 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	result = _tmp1_;
#line 208 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	return result;
#line 2162 "Branch.c"
}


static gchar* tags_sidebar_entry_real_get_sidebar_icon (SidebarSimplePageEntry* base) {
	TagsSidebarEntry * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 211 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TAGS_TYPE_SIDEBAR_ENTRY, TagsSidebarEntry);
#line 212 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp0_ = self->priv->single_tag_icon;
#line 212 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 212 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	result = _tmp1_;
#line 212 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	return result;
#line 2181 "Branch.c"
}


static Page* tags_sidebar_entry_real_create_page (SidebarSimplePageEntry* base) {
	TagsSidebarEntry * self;
	Page* result = NULL;
	Tag* _tmp0_;
	TagPage* _tmp1_;
#line 215 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TAGS_TYPE_SIDEBAR_ENTRY, TagsSidebarEntry);
#line 216 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp0_ = self->priv->tag;
#line 216 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp1_ = tag_page_new (_tmp0_);
#line 216 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	g_object_ref_sink (_tmp1_);
#line 216 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_PAGE, Page);
#line 216 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	return result;
#line 2202 "Branch.c"
}


static gboolean tags_sidebar_entry_real_is_user_renameable (SidebarRenameableEntry* base) {
	TagsSidebarEntry * self;
	gboolean result = FALSE;
#line 219 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TAGS_TYPE_SIDEBAR_ENTRY, TagsSidebarEntry);
#line 220 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	result = TRUE;
#line 220 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	return result;
#line 2215 "Branch.c"
}


static gchar* string_replace (const gchar* self, const gchar* old, const gchar* replacement) {
	gchar* result = NULL;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	GError * _inner_error_ = NULL;
#line 1407 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1407 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	g_return_val_if_fail (old != NULL, NULL);
#line 1407 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	g_return_val_if_fail (replacement != NULL, NULL);
#line 1408 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if ((*((gchar*) self)) == '\0') {
#line 1408 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp1_ = TRUE;
#line 2234 "Branch.c"
	} else {
		const gchar* _tmp2_;
#line 1408 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp2_ = old;
#line 1408 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp1_ = (*((gchar*) _tmp2_)) == '\0';
#line 2241 "Branch.c"
	}
#line 1408 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (_tmp1_) {
#line 1408 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp0_ = TRUE;
#line 2247 "Branch.c"
	} else {
		const gchar* _tmp3_;
		const gchar* _tmp4_;
#line 1408 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp3_ = old;
#line 1408 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp4_ = replacement;
#line 1408 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp0_ = g_strcmp0 (_tmp3_, _tmp4_) == 0;
#line 2257 "Branch.c"
	}
#line 1408 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (_tmp0_) {
#line 2261 "Branch.c"
		gchar* _tmp5_;
#line 1409 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp5_ = g_strdup (self);
#line 1409 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		result = _tmp5_;
#line 1409 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		return result;
#line 2269 "Branch.c"
	}
	{
		GRegex* regex = NULL;
		const gchar* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		GRegex* _tmp9_;
		GRegex* _tmp10_;
		gchar* _tmp11_ = NULL;
		GRegex* _tmp12_;
		const gchar* _tmp13_;
		gchar* _tmp14_;
		gchar* _tmp15_;
#line 1412 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp6_ = old;
#line 1412 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp7_ = g_regex_escape_string (_tmp6_, -1);
#line 1412 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp8_ = _tmp7_;
#line 1412 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp9_ = g_regex_new (_tmp8_, 0, 0, &_inner_error_);
#line 1412 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp10_ = _tmp9_;
#line 1412 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_g_free0 (_tmp8_);
#line 1412 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		regex = _tmp10_;
#line 1412 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1412 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			if (_inner_error_->domain == G_REGEX_ERROR) {
#line 2301 "Branch.c"
				goto __catch56_g_regex_error;
			}
#line 1412 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1412 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			g_clear_error (&_inner_error_);
#line 1412 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			return NULL;
#line 2310 "Branch.c"
		}
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp12_ = regex;
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp13_ = replacement;
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp14_ = g_regex_replace_literal (_tmp12_, self, (gssize) -1, 0, _tmp13_, 0, &_inner_error_);
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp11_ = _tmp14_;
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			_g_regex_unref0 (regex);
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			if (_inner_error_->domain == G_REGEX_ERROR) {
#line 2326 "Branch.c"
				goto __catch56_g_regex_error;
			}
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			_g_regex_unref0 (regex);
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			g_clear_error (&_inner_error_);
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			return NULL;
#line 2337 "Branch.c"
		}
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp15_ = _tmp11_;
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp11_ = NULL;
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		result = _tmp15_;
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_g_free0 (_tmp11_);
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_g_regex_unref0 (regex);
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		return result;
#line 2351 "Branch.c"
	}
	goto __finally56;
	__catch56_g_regex_error:
	{
		GError* e = NULL;
#line 1411 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		e = _inner_error_;
#line 1411 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_inner_error_ = NULL;
#line 1415 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		g_assert_not_reached ();
#line 1411 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_g_error_free0 (e);
#line 2365 "Branch.c"
	}
	__finally56:
#line 1411 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1411 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1411 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		g_clear_error (&_inner_error_);
#line 1411 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		return NULL;
#line 2376 "Branch.c"
	}
}


static void tags_sidebar_entry_real_rename (SidebarRenameableEntry* base, const gchar* new_name) {
	TagsSidebarEntry * self;
	gchar* prepped = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	const gchar* _tmp5_;
	Tag* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	gboolean _tmp9_;
	const gchar* _tmp10_;
	CommandManager* _tmp11_;
	CommandManager* _tmp12_;
	Tag* _tmp13_;
	const gchar* _tmp14_;
	RenameTagCommand* _tmp15_;
	RenameTagCommand* _tmp16_;
#line 223 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TAGS_TYPE_SIDEBAR_ENTRY, TagsSidebarEntry);
#line 223 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	g_return_if_fail (new_name != NULL);
#line 224 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp0_ = new_name;
#line 224 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp1_ = tag_prep_tag_name (_tmp0_);
#line 224 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	prepped = _tmp1_;
#line 225 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp2_ = prepped;
#line 225 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	if (_tmp2_ == NULL) {
#line 226 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_g_free0 (prepped);
#line 226 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		return;
#line 2419 "Branch.c"
	}
#line 228 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp3_ = prepped;
#line 228 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp4_ = string_replace (_tmp3_, "/", "");
#line 228 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_g_free0 (prepped);
#line 228 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	prepped = _tmp4_;
#line 230 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp5_ = prepped;
#line 230 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp6_ = self->priv->tag;
#line 230 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp7_ = tag_get_user_visible_name (_tmp6_);
#line 230 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp8_ = _tmp7_;
#line 230 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp9_ = g_strcmp0 (_tmp5_, _tmp8_) == 0;
#line 230 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_g_free0 (_tmp8_);
#line 230 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	if (_tmp9_) {
#line 231 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_g_free0 (prepped);
#line 231 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		return;
#line 2447 "Branch.c"
	}
#line 233 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp10_ = prepped;
#line 233 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	if (g_strcmp0 (_tmp10_, "") == 0) {
#line 234 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_g_free0 (prepped);
#line 234 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		return;
#line 2457 "Branch.c"
	}
#line 236 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp11_ = app_window_get_command_manager ();
#line 236 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp12_ = _tmp11_;
#line 236 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp13_ = self->priv->tag;
#line 236 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp14_ = prepped;
#line 236 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp15_ = rename_tag_command_new (_tmp13_, _tmp14_);
#line 236 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp16_ = _tmp15_;
#line 236 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	command_manager_execute (_tmp12_, G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, TYPE_COMMAND, Command));
#line 236 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_g_object_unref0 (_tmp16_);
#line 236 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_command_manager_unref0 (_tmp12_);
#line 223 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_g_free0 (prepped);
#line 2479 "Branch.c"
}


static void tags_sidebar_entry_real_destroy_source (SidebarDestroyableEntry* base) {
	TagsSidebarEntry * self;
	Tag* _tmp0_;
	gboolean _tmp1_;
#line 239 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TAGS_TYPE_SIDEBAR_ENTRY, TagsSidebarEntry);
#line 240 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp0_ = self->priv->tag;
#line 240 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp1_ = dialogs_confirm_delete_tag (_tmp0_);
#line 240 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	if (_tmp1_) {
#line 2495 "Branch.c"
		CommandManager* _tmp2_;
		CommandManager* _tmp3_;
		Tag* _tmp4_;
		DeleteTagCommand* _tmp5_;
		DeleteTagCommand* _tmp6_;
#line 241 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp2_ = app_window_get_command_manager ();
#line 241 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp3_ = _tmp2_;
#line 241 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp4_ = self->priv->tag;
#line 241 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp5_ = delete_tag_command_new (_tmp4_);
#line 241 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp6_ = _tmp5_;
#line 241 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		command_manager_execute (_tmp3_, G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, TYPE_COMMAND, Command));
#line 241 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_g_object_unref0 (_tmp6_);
#line 241 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_command_manager_unref0 (_tmp3_);
#line 2517 "Branch.c"
	}
}


static gboolean tags_sidebar_entry_real_internal_drop_received (SidebarInternalDropTargetEntry* base, GeeList* media) {
	TagsSidebarEntry * self;
	gboolean result = FALSE;
	CommandManager* _tmp0_;
	CommandManager* _tmp1_;
	Tag* _tmp2_;
	GeeList* _tmp3_;
	GeeList* _tmp4_;
	gint _tmp5_;
	gint _tmp6_;
	TagUntagPhotosCommand* _tmp7_;
	TagUntagPhotosCommand* _tmp8_;
#line 244 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TAGS_TYPE_SIDEBAR_ENTRY, TagsSidebarEntry);
#line 244 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	g_return_val_if_fail (GEE_IS_LIST (media), FALSE);
#line 245 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp0_ = app_window_get_command_manager ();
#line 245 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp1_ = _tmp0_;
#line 245 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp2_ = self->priv->tag;
#line 245 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp3_ = media;
#line 245 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp4_ = media;
#line 245 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp5_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, GEE_TYPE_COLLECTION, GeeCollection));
#line 245 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp6_ = _tmp5_;
#line 245 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp7_ = tag_untag_photos_command_new (_tmp2_, G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_COLLECTION, GeeCollection), _tmp6_, TRUE);
#line 245 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp8_ = _tmp7_;
#line 245 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	command_manager_execute (_tmp1_, G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, TYPE_COMMAND, Command));
#line 245 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_g_object_unref0 (_tmp8_);
#line 245 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_command_manager_unref0 (_tmp1_);
#line 248 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	result = TRUE;
#line 248 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	return result;
#line 2566 "Branch.c"
}


static gboolean tags_sidebar_entry_real_internal_drop_received_arbitrary (SidebarInternalDropTargetEntry* base, GtkSelectionData* data) {
	TagsSidebarEntry * self;
	gboolean result = FALSE;
	GtkSelectionData* _tmp0_;
	GdkAtom _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gboolean _tmp4_;
#line 251 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TAGS_TYPE_SIDEBAR_ENTRY, TagsSidebarEntry);
#line 251 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	g_return_val_if_fail (data != NULL, FALSE);
#line 252 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp0_ = data;
#line 252 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp1_ = gtk_selection_data_get_data_type (_tmp0_);
#line 252 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp2_ = gdk_atom_name (_tmp1_);
#line 252 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp3_ = _tmp2_;
#line 252 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp4_ = g_strcmp0 (_tmp3_, LIBRARY_WINDOW_TAG_PATH_MIME_TYPE) == 0;
#line 252 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_g_free0 (_tmp3_);
#line 252 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	if (_tmp4_) {
#line 2596 "Branch.c"
		gchar* old_tag_path = NULL;
		GtkSelectionData* _tmp5_;
		guchar* _tmp6_;
		gchar* _tmp7_;
		const gchar* _tmp8_;
		Tag* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
		gboolean _tmp12_;
		TagSourceCollection* _tmp29_;
		const gchar* _tmp30_;
		gboolean _tmp31_;
		Tag* old_tag = NULL;
		const gchar* _tmp32_;
		Tag* _tmp33_;
		Tag* old_tag_parent = NULL;
		Tag* _tmp34_;
		Tag* _tmp35_;
		gboolean _tmp36_ = FALSE;
		Tag* _tmp37_;
		CommandManager* _tmp44_;
		CommandManager* _tmp45_;
		Tag* _tmp46_;
		Tag* _tmp47_;
		gchar* _tmp48_;
		gchar* _tmp49_;
		ReparentTagCommand* _tmp50_;
		ReparentTagCommand* _tmp51_;
#line 253 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp5_ = data;
#line 253 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp6_ = gtk_selection_data_get_data (_tmp5_);
#line 253 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp7_ = g_strdup ((const gchar*) _tmp6_);
#line 253 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		old_tag_path = _tmp7_;
#line 256 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp8_ = old_tag_path;
#line 256 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp9_ = self->priv->tag;
#line 256 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp10_ = tag_get_path (_tmp9_);
#line 256 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp11_ = _tmp10_;
#line 256 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp12_ = g_strcmp0 (_tmp8_, _tmp11_) == 0;
#line 256 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_g_free0 (_tmp11_);
#line 256 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		if (_tmp12_) {
#line 257 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			result = TRUE;
#line 257 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_g_free0 (old_tag_path);
#line 257 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			return result;
#line 2653 "Branch.c"
		}
		{
			GeeList* _parent_path_list = NULL;
			Tag* _tmp13_;
			gchar* _tmp14_;
			gchar* _tmp15_;
			GeeList* _tmp16_;
			GeeList* _tmp17_;
			gint _parent_path_size = 0;
			GeeList* _tmp18_;
			gint _tmp19_;
			gint _tmp20_;
			gint _parent_path_index = 0;
#line 260 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp13_ = self->priv->tag;
#line 260 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp14_ = tag_get_path (_tmp13_);
#line 260 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp15_ = _tmp14_;
#line 260 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp16_ = hierarchical_tag_utilities_enumerate_parent_paths (_tmp15_);
#line 260 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp17_ = _tmp16_;
#line 260 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_g_free0 (_tmp15_);
#line 260 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_parent_path_list = _tmp17_;
#line 260 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp18_ = _parent_path_list;
#line 260 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp19_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, GEE_TYPE_COLLECTION, GeeCollection));
#line 260 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp20_ = _tmp19_;
#line 260 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_parent_path_size = _tmp20_;
#line 260 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_parent_path_index = -1;
#line 260 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			while (TRUE) {
#line 2693 "Branch.c"
				gint _tmp21_;
				gint _tmp22_;
				gint _tmp23_;
				gchar* parent_path = NULL;
				GeeList* _tmp24_;
				gint _tmp25_;
				gpointer _tmp26_;
				const gchar* _tmp27_;
				const gchar* _tmp28_;
#line 260 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp21_ = _parent_path_index;
#line 260 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_parent_path_index = _tmp21_ + 1;
#line 260 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp22_ = _parent_path_index;
#line 260 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp23_ = _parent_path_size;
#line 260 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				if (!(_tmp22_ < _tmp23_)) {
#line 260 "/home/jens/Source/shotwell/src/tags/Branch.vala"
					break;
#line 2715 "Branch.c"
				}
#line 260 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp24_ = _parent_path_list;
#line 260 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp25_ = _parent_path_index;
#line 260 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp26_ = gee_list_get (_tmp24_, _tmp25_);
#line 260 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				parent_path = (gchar*) _tmp26_;
#line 261 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp27_ = parent_path;
#line 261 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_tmp28_ = old_tag_path;
#line 261 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				if (g_strcmp0 (_tmp27_, _tmp28_) == 0) {
#line 262 "/home/jens/Source/shotwell/src/tags/Branch.vala"
					result = TRUE;
#line 262 "/home/jens/Source/shotwell/src/tags/Branch.vala"
					_g_free0 (parent_path);
#line 262 "/home/jens/Source/shotwell/src/tags/Branch.vala"
					_g_object_unref0 (_parent_path_list);
#line 262 "/home/jens/Source/shotwell/src/tags/Branch.vala"
					_g_free0 (old_tag_path);
#line 262 "/home/jens/Source/shotwell/src/tags/Branch.vala"
					return result;
#line 2741 "Branch.c"
				}
#line 260 "/home/jens/Source/shotwell/src/tags/Branch.vala"
				_g_free0 (parent_path);
#line 2745 "Branch.c"
			}
#line 260 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_g_object_unref0 (_parent_path_list);
#line 2749 "Branch.c"
		}
#line 265 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp29_ = tag_global;
#line 265 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp30_ = old_tag_path;
#line 265 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp31_ = tag_source_collection_exists (_tmp29_, _tmp30_, FALSE);
#line 265 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_vala_assert (_tmp31_, "Tag.global.exists(old_tag_path)");
#line 268 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp32_ = old_tag_path;
#line 268 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp33_ = tag_for_path (_tmp32_);
#line 268 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		old_tag = _tmp33_;
#line 269 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp34_ = old_tag;
#line 269 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp35_ = tag_get_hierarchical_parent (_tmp34_);
#line 269 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		old_tag_parent = _tmp35_;
#line 270 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp37_ = old_tag_parent;
#line 270 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		if (_tmp37_ != NULL) {
#line 2775 "Branch.c"
			Tag* _tmp38_;
			gchar* _tmp39_;
			gchar* _tmp40_;
			Tag* _tmp41_;
			gchar* _tmp42_;
			gchar* _tmp43_;
#line 270 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp38_ = old_tag_parent;
#line 270 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp39_ = tag_get_path (_tmp38_);
#line 270 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp40_ = _tmp39_;
#line 270 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp41_ = self->priv->tag;
#line 270 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp42_ = tag_get_path (_tmp41_);
#line 270 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp43_ = _tmp42_;
#line 270 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp36_ = g_strcmp0 (_tmp40_, _tmp43_) == 0;
#line 270 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_g_free0 (_tmp43_);
#line 270 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_g_free0 (_tmp40_);
#line 2800 "Branch.c"
		} else {
#line 270 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_tmp36_ = FALSE;
#line 2804 "Branch.c"
		}
#line 270 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		if (_tmp36_) {
#line 271 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			result = TRUE;
#line 271 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_g_object_unref0 (old_tag_parent);
#line 271 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_g_object_unref0 (old_tag);
#line 271 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			_g_free0 (old_tag_path);
#line 271 "/home/jens/Source/shotwell/src/tags/Branch.vala"
			return result;
#line 2818 "Branch.c"
		}
#line 273 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp44_ = app_window_get_command_manager ();
#line 273 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp45_ = _tmp44_;
#line 273 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp46_ = old_tag;
#line 273 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp47_ = self->priv->tag;
#line 273 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp48_ = tag_get_path (_tmp47_);
#line 273 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp49_ = _tmp48_;
#line 273 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp50_ = reparent_tag_command_new (_tmp46_, _tmp49_);
#line 273 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_tmp51_ = _tmp50_;
#line 273 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		command_manager_execute (_tmp45_, G_TYPE_CHECK_INSTANCE_CAST (_tmp51_, TYPE_COMMAND, Command));
#line 273 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_g_object_unref0 (_tmp51_);
#line 273 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_g_free0 (_tmp49_);
#line 273 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_command_manager_unref0 (_tmp45_);
#line 276 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		result = TRUE;
#line 276 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_g_object_unref0 (old_tag_parent);
#line 276 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_g_object_unref0 (old_tag);
#line 276 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		_g_free0 (old_tag_path);
#line 276 "/home/jens/Source/shotwell/src/tags/Branch.vala"
		return result;
#line 2854 "Branch.c"
	}
#line 279 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	result = FALSE;
#line 279 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	return result;
#line 2860 "Branch.c"
}


static gboolean tags_sidebar_entry_real_expand_on_select (SidebarExpandableEntry* base) {
	TagsSidebarEntry * self;
	gboolean result = FALSE;
#line 282 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TAGS_TYPE_SIDEBAR_ENTRY, TagsSidebarEntry);
#line 283 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	result = FALSE;
#line 283 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	return result;
#line 2873 "Branch.c"
}


static guint8* string_get_data (const gchar* self, int* result_length1) {
	guint8* result;
	guint8* res = NULL;
	gint res_length1;
	gint _res_size_;
	gint _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
	guint8* _tmp3_;
	gint _tmp3__length1;
	guint8* _tmp4_;
	gint _tmp4__length1;
#line 1428 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1429 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	res = (guint8*) self;
#line 1429 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	res_length1 = -1;
#line 1429 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_res_size_ = res_length1;
#line 1430 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp0_ = strlen (self);
#line 1430 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp1_ = _tmp0_;
#line 1430 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	res_length1 = (gint) _tmp1_;
#line 1430 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp2_ = res_length1;
#line 1431 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp3_ = res;
#line 1431 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp3__length1 = res_length1;
#line 1431 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp4_ = _tmp3_;
#line 1431 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp4__length1 = _tmp3__length1;
#line 1431 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (result_length1) {
#line 1431 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		*result_length1 = _tmp4__length1;
#line 2917 "Branch.c"
	}
#line 1431 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	result = _tmp4_;
#line 1431 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	return result;
#line 2923 "Branch.c"
}


static void tags_sidebar_entry_real_prepare_selection_data (SidebarInternalDragSourceEntry* base, GtkSelectionData* data) {
	TagsSidebarEntry * self;
	GtkSelectionData* _tmp0_;
	GdkAtom _tmp1_;
	Tag* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	guint8* _tmp5_;
	gint _tmp5__length1;
	guint8* _tmp6_;
	gint _tmp6__length1;
#line 286 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TAGS_TYPE_SIDEBAR_ENTRY, TagsSidebarEntry);
#line 286 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	g_return_if_fail (data != NULL);
#line 287 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp0_ = data;
#line 287 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp1_ = gdk_atom_intern_static_string (LIBRARY_WINDOW_TAG_PATH_MIME_TYPE);
#line 287 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp2_ = self->priv->tag;
#line 287 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp3_ = tag_get_path (_tmp2_);
#line 287 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp4_ = _tmp3_;
#line 287 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp5_ = string_get_data (_tmp4_, &_tmp5__length1);
#line 287 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp6_ = _tmp5_;
#line 287 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp6__length1 = _tmp5__length1;
#line 287 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	gtk_selection_data_set (_tmp0_, _tmp1_, 0, _tmp6_, _tmp6__length1);
#line 287 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_g_free0 (_tmp4_);
#line 2962 "Branch.c"
}


static void tags_sidebar_entry_class_init (TagsSidebarEntryClass * klass) {
#line 186 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	tags_sidebar_entry_parent_class = g_type_class_peek_parent (klass);
#line 186 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	g_type_class_add_private (klass, sizeof (TagsSidebarEntryPrivate));
#line 186 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	((SidebarSimplePageEntryClass *) klass)->get_sidebar_name = (gchar* (*) (SidebarSimplePageEntry *)) tags_sidebar_entry_real_get_sidebar_name;
#line 186 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	((SidebarSimplePageEntryClass *) klass)->get_sidebar_icon = (gchar* (*) (SidebarSimplePageEntry *)) tags_sidebar_entry_real_get_sidebar_icon;
#line 186 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	((SidebarSimplePageEntryClass *) klass)->create_page = (Page* (*) (SidebarSimplePageEntry *)) tags_sidebar_entry_real_create_page;
#line 186 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	G_OBJECT_CLASS (klass)->finalize = tags_sidebar_entry_finalize;
#line 2979 "Branch.c"
}


static void tags_sidebar_entry_sidebar_renameable_entry_interface_init (SidebarRenameableEntryIface * iface) {
#line 186 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	tags_sidebar_entry_sidebar_renameable_entry_parent_iface = g_type_interface_peek_parent (iface);
#line 186 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	iface->is_user_renameable = (gboolean (*) (SidebarRenameableEntry *)) tags_sidebar_entry_real_is_user_renameable;
#line 186 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	iface->rename = (void (*) (SidebarRenameableEntry *, const gchar*)) tags_sidebar_entry_real_rename;
#line 2990 "Branch.c"
}


static void tags_sidebar_entry_sidebar_destroyable_entry_interface_init (SidebarDestroyableEntryIface * iface) {
#line 186 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	tags_sidebar_entry_sidebar_destroyable_entry_parent_iface = g_type_interface_peek_parent (iface);
#line 186 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	iface->destroy_source = (void (*) (SidebarDestroyableEntry *)) tags_sidebar_entry_real_destroy_source;
#line 2999 "Branch.c"
}


static void tags_sidebar_entry_sidebar_internal_drop_target_entry_interface_init (SidebarInternalDropTargetEntryIface * iface) {
#line 186 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	tags_sidebar_entry_sidebar_internal_drop_target_entry_parent_iface = g_type_interface_peek_parent (iface);
#line 186 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	iface->internal_drop_received = (gboolean (*) (SidebarInternalDropTargetEntry *, GeeList*)) tags_sidebar_entry_real_internal_drop_received;
#line 186 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	iface->internal_drop_received_arbitrary = (gboolean (*) (SidebarInternalDropTargetEntry *, GtkSelectionData*)) tags_sidebar_entry_real_internal_drop_received_arbitrary;
#line 3010 "Branch.c"
}


static void tags_sidebar_entry_sidebar_expandable_entry_interface_init (SidebarExpandableEntryIface * iface) {
#line 186 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	tags_sidebar_entry_sidebar_expandable_entry_parent_iface = g_type_interface_peek_parent (iface);
#line 186 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	iface->expand_on_select = (gboolean (*) (SidebarExpandableEntry *)) tags_sidebar_entry_real_expand_on_select;
#line 3019 "Branch.c"
}


static void tags_sidebar_entry_sidebar_internal_drag_source_entry_interface_init (SidebarInternalDragSourceEntryIface * iface) {
#line 186 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	tags_sidebar_entry_sidebar_internal_drag_source_entry_parent_iface = g_type_interface_peek_parent (iface);
#line 186 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	iface->prepare_selection_data = (void (*) (SidebarInternalDragSourceEntry *, GtkSelectionData*)) tags_sidebar_entry_real_prepare_selection_data;
#line 3028 "Branch.c"
}


static void tags_sidebar_entry_instance_init (TagsSidebarEntry * self) {
	gchar* _tmp0_;
#line 186 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	self->priv = TAGS_SIDEBAR_ENTRY_GET_PRIVATE (self);
#line 189 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_tmp0_ = g_strdup (RESOURCES_ICON_ONE_TAG);
#line 189 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	self->priv->single_tag_icon = _tmp0_;
#line 3040 "Branch.c"
}


static void tags_sidebar_entry_finalize (GObject * obj) {
	TagsSidebarEntry * self;
#line 186 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TAGS_TYPE_SIDEBAR_ENTRY, TagsSidebarEntry);
#line 189 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_g_free0 (self->priv->single_tag_icon);
#line 191 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	_g_object_unref0 (self->priv->tag);
#line 186 "/home/jens/Source/shotwell/src/tags/Branch.vala"
	G_OBJECT_CLASS (tags_sidebar_entry_parent_class)->finalize (obj);
#line 3054 "Branch.c"
}


GType tags_sidebar_entry_get_type (void) {
	static volatile gsize tags_sidebar_entry_type_id__volatile = 0;
	if (g_once_init_enter (&tags_sidebar_entry_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (TagsSidebarEntryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tags_sidebar_entry_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TagsSidebarEntry), 0, (GInstanceInitFunc) tags_sidebar_entry_instance_init, NULL };
		static const GInterfaceInfo sidebar_renameable_entry_info = { (GInterfaceInitFunc) tags_sidebar_entry_sidebar_renameable_entry_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo sidebar_destroyable_entry_info = { (GInterfaceInitFunc) tags_sidebar_entry_sidebar_destroyable_entry_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo sidebar_internal_drop_target_entry_info = { (GInterfaceInitFunc) tags_sidebar_entry_sidebar_internal_drop_target_entry_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo sidebar_expandable_entry_info = { (GInterfaceInitFunc) tags_sidebar_entry_sidebar_expandable_entry_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo sidebar_internal_drag_source_entry_info = { (GInterfaceInitFunc) tags_sidebar_entry_sidebar_internal_drag_source_entry_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType tags_sidebar_entry_type_id;
		tags_sidebar_entry_type_id = g_type_register_static (SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY, "TagsSidebarEntry", &g_define_type_info, 0);
		g_type_add_interface_static (tags_sidebar_entry_type_id, SIDEBAR_TYPE_RENAMEABLE_ENTRY, &sidebar_renameable_entry_info);
		g_type_add_interface_static (tags_sidebar_entry_type_id, SIDEBAR_TYPE_DESTROYABLE_ENTRY, &sidebar_destroyable_entry_info);
		g_type_add_interface_static (tags_sidebar_entry_type_id, SIDEBAR_TYPE_INTERNAL_DROP_TARGET_ENTRY, &sidebar_internal_drop_target_entry_info);
		g_type_add_interface_static (tags_sidebar_entry_type_id, SIDEBAR_TYPE_EXPANDABLE_ENTRY, &sidebar_expandable_entry_info);
		g_type_add_interface_static (tags_sidebar_entry_type_id, SIDEBAR_TYPE_INTERNAL_DRAG_SOURCE_ENTRY, &sidebar_internal_drag_source_entry_info);
		g_once_init_leave (&tags_sidebar_entry_type_id__volatile, tags_sidebar_entry_type_id);
	}
	return tags_sidebar_entry_type_id__volatile;
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



